<?php
session_start();
include 'db_connect.php'; 

if (!$conn) {
    die("Erreur de connexion à la base de données : " . mysqli_connect_error());
}

function executeQuery($conn, $query) {
    $result = $conn->query($query);
    if (!$result) {
        die("Erreur dans la requête SQL : " . $conn->error);
    }
    return $result;
}

$queryGrosCount = "SELECT COUNT(*) AS gros_count FROM products WHERE type_pro = 'gros'";
$queryDetailsCount = "SELECT COUNT(*) AS details_count FROM products WHERE type_pro = 'details'";
$queryGrosAmount = "SELECT SUM(price) AS gros_amount FROM products WHERE type_pro = 'gros'";
$queryDetailsAmount = "SELECT SUM(price) AS details_amount FROM products WHERE type_pro = 'details'";
$querySuppliersCount = "SELECT COUNT(*) AS suppliers_count FROM fournisseurs";
$queryRestocksCount = "SELECT COUNT(*) AS restocks_count FROM ravitaillements";
$queryTotalSales = "SELECT SUM(montant_total) AS total_sales FROM ventes";

$grosCount = executeQuery($conn, $queryGrosCount)->fetch_assoc()['gros_count'];
$detailsCount = executeQuery($conn, $queryDetailsCount)->fetch_assoc()['details_count'];
$grosAmount = executeQuery($conn, $queryGrosAmount)->fetch_assoc()['gros_amount'];
$detailsAmount = executeQuery($conn, $queryDetailsAmount)->fetch_assoc()['details_amount'];
$suppliersCount = executeQuery($conn, $querySuppliersCount)->fetch_assoc()['suppliers_count'];
$restocksCount = executeQuery($conn, $queryRestocksCount)->fetch_assoc()['restocks_count'];
$totalSales = executeQuery($conn, $queryTotalSales)->fetch_assoc()['total_sales'];

$queryMonthlySales = "SELECT MONTH(date_heure) AS month, SUM(montant_total) AS total FROM ventes GROUP BY MONTH(date_heure)";
$resultMonthlySales = executeQuery($conn, $queryMonthlySales);
$monthlySales = [];
while ($row = $resultMonthlySales->fetch_assoc()) {
    $monthlySales[] = $row;
}

$queryDailySales = "SELECT DATE(date_heure) AS day, SUM(montant_total) AS total FROM ventes GROUP BY DATE(date_heure)";
$resultDailySales = executeQuery($conn, $queryDailySales);
$dailySales = [];
while ($row = $resultDailySales->fetch_assoc()) {
    $dailySales[] = $row;
}

$conn->close();
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Statistiques</title>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #2563eb;
            --secondary-color: #475569;
            --accent-color: #f97316;
            --background-color: #f8fafc;
            --card-background: #ffffff;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Segoe UI', system-ui, sans-serif;
            margin: 0;
            padding: 2rem;
            background-color: var(--background-color);
            color: var(--secondary-color);
            min-height: 100vh;
        }

        h1 {
            font-size: 2.5rem;
            color: var(--primary-color);
            margin-bottom: 2rem;
            text-align: center;
            position: relative;
            padding-bottom: 0.5rem;
        }

        h1::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 50%;
            transform: translateX(-50%);
            width: 100px;
            height: 4px;
            background: var(--primary-color);
            border-radius: 2px;
        }

        .stats {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 1.5rem;
            margin-bottom: 3rem;
            padding: 0.5rem;
        }

        .stat-box {
            background: var(--card-background);
            padding: 1.5rem;
            border-radius: 1rem;
            box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
            transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        .stat-box:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
        }

        .stat-box i {
            font-size: 2rem;
            color: var(--primary-color);
            margin-bottom: 1rem;
        }

        .stat-box span {
            color: var(--secondary-color);
            font-size: 1rem;
            text-align: center;
            margin-bottom: 0.5rem;
        }

        .stat-box strong {
            font-size: 1.5rem;
            color: var(--primary-color);
            margin-top: 0.5rem;
        }

        .charts {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(450px, 1fr));
            gap: 2rem;
            margin-top: 2rem;
            padding: 0.5rem;
        }

        .chart-container {
            background: var(--card-background);
            padding: 1.5rem;
            border-radius: 1rem;
            box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1);
        }

        h2 {
            color: var(--secondary-color);
            font-size: 1.5rem;
            margin-bottom: 1.5rem;
            text-align: center;
        }

        canvas {
            width: 100% !important;
            height: 300px !important;
        }

        @media (max-width: 768px) {
            body {
                padding: 1rem;
            }
            
            .charts {
                grid-template-columns: 1fr;
            }
            
            h1 {
                font-size: 2rem;
            }
            
            .stat-box {
                padding: 1rem;
            }
        }

        @media (max-width: 480px) {
            .stats {
                grid-template-columns: 1fr;
            }
            
            h1 {
                font-size: 1.75rem;
            }
        }
    </style>
</head>
<body>
    <h1>Les statistiques</h1>

    <div class="stats">
        <div class="stat-box">
            <i class="fas fa-box"></i>
            <span>Produits de type Gros</span>
            <strong><?= $grosCount ?></strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-boxes"></i>
            <span>Produits de type Détails</span>
            <strong><?= $detailsCount ?></strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-euro-sign"></i>
            <span>Montant Produits Gros</span>
            <strong><?= number_format($grosAmount) ?> FCFA</strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-coins"></i>
            <span>Montant Produits Détails</span>
            <strong><?= number_format($detailsAmount) ?> FCFA</strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-truck"></i>
            <span>Fournisseurs</span>
            <strong><?= $suppliersCount ?></strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-warehouse"></i>
            <span>Ravitaillements</span>
            <strong><?= $restocksCount ?></strong>
        </div>
        <div class="stat-box">
            <i class="fas fa-chart-line"></i>
            <span>Montant Total des Ventes</span>
            <strong><?= number_format($totalSales) ?> FCFA</strong>
        </div>
    </div>

    <div class="charts">
        <div class="chart-container">
            <h2>Évolution des Recettes Mensuelles</h2>
            <canvas id="monthlyChart"></canvas>
        </div>
        <div class="chart-container">
            <h2>Recettes Journalières</h2>
            <canvas id="dailyChart"></canvas>
        </div>
    </div>

    <script>
        Chart.defaults.font.family = "'Segoe UI', system-ui, sans-serif";
        Chart.defaults.font.size = 14;
        Chart.defaults.color = '#475569';

        const monthlySales = <?= json_encode($monthlySales) ?>;
        const dailySales = <?= json_encode($dailySales) ?>;

        new Chart(document.getElementById('monthlyChart'), {
            type: 'line',
            data: {
                labels: monthlySales.map(sale => `Mois ${sale.month}`),
                datasets: [{
                    label: 'Recette Mensuelle (FCFA)',
                    data: monthlySales.map(sale => sale.total),
                    borderColor: '#2563eb',
                    backgroundColor: 'rgba(37, 99, 235, 0.1)',
                    fill: true,
                    tension: 0.4,
                    pointRadius: 6,
                    pointHoverRadius: 8,
                    pointBackgroundColor: '#ffffff',
                    pointBorderColor: '#2563eb',
                    pointBorderWidth: 2
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'top',
                        labels: {
                            padding: 20,
                            font: {
                                size: 12
                            }
                        }
                    },
                    tooltip: {
                        backgroundColor: 'rgba(255, 255, 255, 0.9)',
                        titleColor: '#1e293b',
                        bodyColor: '#475569',
                        borderColor: '#e2e8f0',
                        borderWidth: 1,
                        padding: 12,
                        displayColors: false,
                        callbacks: {
                            label: function(context) {
                                return new Intl.NumberFormat('fr-FR', { 
                                    style: 'currency', 
                                    currency: 'EUR' 
                                }).format(context.parsed.y);
                            }
                        }
                    }
                },
                scales: {
                    y: {
                        beginAtZero: true,
                        grid: {
                            color: 'rgba(0, 0, 0, 0.05)'
                        },
                        ticks: {
                            callback: function(value) {
                                return new Intl.NumberFormat('fr-FR', {
                                    style: 'currency',
                                    currency: 'EUR',
                                    maximumFractionDigits: 0
                                }).format(value);
                            }
                        }
                    },
                    x: {
                        grid: {
                            display: false
                        }
                    }
                }
            }
        });

        new Chart(document.getElementById('dailyChart'), {
            type: 'bar',
            data: {
                labels: dailySales.map(sale => sale.day),
                datasets: [{
                    label: 'Recette Journalière (FCFA)',
                    data: dailySales.map(sale => sale.total),
                    backgroundColor: '#f97316',
                    borderRadius: 6,
                    borderSkipped: false,
                    hoverBackgroundColor: '#ea580c'
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        position: 'top',
                        labels: {
                            padding: 20,
                            font: {
                                size: 12
                            }
                        }
                    },
                    tooltip: {
                        backgroundColor: 'rgba(255, 255, 255, 0.9)',
                        titleColor: '#1e293b',
                        bodyColor: '#475569',
                        borderColor: '#e2e8f0',
                        borderWidth: 1,
                        padding: 12,
                        displayColors: false,
                        callbacks: {
                            label: function(context) {
                                return new Intl.NumberFormat('fr-FR', { 
                                    style: 'currency', 
                                    currency: 'FCFA' 
                                }).format(context.parsed.y);
                            }
                        }
                    }
                },
                scales: {
                    y: {
                        beginAtZero: true,
                        grid: {
                            color: 'rgba(0, 0, 0, 0.05)'
                        },
                        ticks: {
                            callback: function(value) {
                                return new Intl.NumberFormat('fr-FR', {
                                    style: 'currency',
                                    currency: 'EUR',
                                    maximumFractionDigits: 0
                                }).format(value);
                            }
                        }
                    },
                    x: {
                        grid: {
                            display: false
                        }
                    }
                }
            }
        });
    </script>
</body>
</html>