<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

include 'db_connect.php';

// [Previous PHP functions remain unchanged: getSalesMetrics, getRecentSales, getChartData]
function getSalesMetrics($conn) {
    $metrics = [
        'total_purchases' => 0,
        'total_sales' => 0,
        'total_profit' => 0,
        'sales_count' => 0
    ];
    
    try {
        $result = $conn->query("SELECT SUM(quantite * prix) AS total FROM commandes");
        $metrics['total_purchases'] = $result->fetch_assoc()['total'] ?? 0;

        $result = $conn->query("SELECT SUM(stock * price) AS total FROM products");
        $metrics['total_sales'] = $result->fetch_assoc()['total'] ?? 0;

        $result = $conn->query("SELECT SUM(c.quantite * (p.price - c.prix)) AS total 
                               FROM commandes c 
                               JOIN products p ON c.id = p.id");
        $metrics['total_profit'] = $result->fetch_assoc()['total'] ?? 0;

        $result = $conn->query("SELECT COUNT(DISTINCT date_heure) AS total FROM ventes");
        $metrics['sales_count'] = $result->fetch_assoc()['total'] ?? 0;
    } catch (Exception $e) {
        error_log("Metrics error: " . $e->getMessage());
    }
    
    return $metrics;
}

function getRecentSales($conn) {
    $sales = [];
    try {
        $result = $conn->query("SELECT nom_pro, tt_pro, montant_total, date_heure 
                               FROM ventes 
                               ORDER BY date_heure DESC 
                               LIMIT 5");
        while ($row = $result->fetch_assoc()) {
            $sales[] = $row;
        }
    } catch (Exception $e) {
        error_log("Recent sales error: " . $e->getMessage());
    }
    return $sales;
}

function getChartData($conn) {
    $weekly = $monthly = $yearly = ['labels' => [], 'values' => []];
    
    try {
        // Weekly data
        $result = $conn->query("
            SELECT DATE(date_heure) as label, SUM(montant_total) as value 
            FROM ventes 
            WHERE date_heure >= DATE_SUB(CURRENT_DATE, INTERVAL 7 DAY)
            GROUP BY DATE(date_heure)
            ORDER BY date_heure
        ");
        while ($row = $result->fetch_assoc()) {
            $weekly['labels'][] = date('D', strtotime($row['label']));
            $weekly['values'][] = $row['value'];
        }

        // Monthly data
        $result = $conn->query("
            SELECT WEEK(date_heure) as label, SUM(montant_total) as value 
            FROM ventes 
            WHERE MONTH(date_heure) = MONTH(CURRENT_DATE)
            GROUP BY WEEK(date_heure)
            ORDER BY label
        ");
        while ($row = $result->fetch_assoc()) {
            $monthly['labels'][] = 'Semaine ' . $row['label'];
            $monthly['values'][] = $row['value'];
        }

        // Yearly data
        $result = $conn->query("
            SELECT MONTH(date_heure) as label, SUM(montant_total) as value 
            FROM ventes 
            WHERE YEAR(date_heure) = YEAR(CURRENT_DATE)
            GROUP BY MONTH(date_heure)
            ORDER BY label
        ");
        while ($row = $result->fetch_assoc()) {
            $yearly['labels'][] = date('M', mktime(0, 0, 0, $row['label'], 1));
            $yearly['values'][] = $row['value'];
        }
    } catch (Exception $e) {
        error_log("Chart data error: " . $e->getMessage());
    }
    
    return [
        'weekly' => $weekly,
        'monthly' => $monthly,
        'yearly' => $yearly
    ];
}

$metrics = getSalesMetrics($conn);
$recentSales = getRecentSales($conn);
$chartData = getChartData($conn);


$query = "SELECT date_heure, montant_total FROM ventes ORDER BY date_heure";
$result = mysqli_query($conn, $query);

$data = [];
while($row = mysqli_fetch_assoc($result)) {
    $data[] = $row;
}
$jsonData = json_encode($data);
$conn->close();
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>BADIE SERVICES - Dashboard</title>
    <style>
        :root {
            --cyan: #00BCD4;
            --green: #8BC34A;
            --orange: #FF9800;
            --primary-blue: #2196F3;
        }
        
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Roboto', Arial, sans-serif;
            background: #f5f5f5;
        }
        
        .top-bar {
            background: var(--primary-blue);
            color: white;
            padding: 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            height: 70px;
        }
        
        .logo-space {
            flex: 1;
            display: flex;
            justify-content: center;
            align-items: center;
            gap: 20px;
        }
        
        .logo-space img {
            width: 40px;
            height: 40px;
        }
        
        .company-name {
            font-weight: bold;
            font-size: 1.5em;
        }
        
        .icons {
            display: flex;
            gap: 20px;
            margin-right: 20px;
        }
        
        .sidebar {
            width: 250px;
            background: var(--primary-blue);
            height: calc(100vh - 70px);
            position: fixed;
            left: 0;
            box-shadow: 2px 0 5px rgba(0,0,0,0.1);
            color: white;
        }
        
        .profile-section {
            background: white;
            padding: 0;
            height: 150px;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        
        .profile-section img {
            max-width: 100%;
            max-height: 100%;
            object-fit: contain;
        }
        
        .nav-item {
            padding: 12px 15px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: background 0.3s;
            text-align: center;
        }
        
        .nav-item:hover {
            background: rgba(255,255,255,0.1);
        }
        
        .dashboard-cards {
            margin-left: 300px;
            padding: 20px;
            display: flex;
            gap: 20px;
            flex-wrap: nowrap;
        }
        
        /* [Rest of the CSS remains unchanged] */
        .info-box {
            flex: 1;
            color: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        
        .info-box.purchase { background: var(--green); }
        .info-box.sales { background: var(--cyan); }
        .info-box.profit { background: var(--green); }
        .info-box.count { background: var(--orange); }
        
        .chart-container {
            margin: 20px 20px 20px 300px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 20px;
        }
        
        .chart-item {
            background: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            height: 300px;
        }
        
        .task-list {
            margin: 20px 20px 20px 300px;
            background: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        
        .task-list table {
            width: 100%;
            border-collapse: collapse;
        }
        
        .task-list th, .task-list td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .task-list th {
            background: var(--primary-blue);
            color: white;
        }
        
        .task-list tr:hover {
            background: #f5f5f5;
        }
    .menu {
  display: flex;
  gap: 1.5rem;
  list-style: none;
  margin: 0;
  padding: 1rem;
  background-color: transparent; /* Enlever le fond */
  box-shadow: none; /* Enlever l'ombre */
}

.menu-item {
  text-decoration: none;
  color: white;
  font-weight: bold;
  font-size: 0.9rem;
  padding: 0.5rem 1rem;
  transition: color 0.3s ease; /* Transition pour un effet fluide */
}

.menu-item:hover {
  color: orange; /* Applique la couleur orange au survol */
}

    </style>
</head>
<body>
    <div class="top-bar">
       <header class="header">
  <nav>
    <ul class="menu">
      <li><a class="menu-item" href="administrateur.php">ACCUEIL</a></li>
      <li><a class="menu-item" href="page_fournisseur.php">FOURNISSEURS</a></li>
      <li><a class="menu-item" href="page_produit.php">PRODUITS</a></li>
      <li><a class="menu-item" href="page_commande.php">COMMANDES</a></li>
      <li><a class="menu-item" href="page_utilisateur.php">UTILISATEURS</a></li>
      <li><a class="menu-item" href="benefice_produit.php">VOIR BENEFICES</a></li>
      
      <li><a class="menu-item" href="depense_tt.php">VOIR DEPENSE</a></li>
      <li><a class="menu-item" href="index.php">DECONNEXION</a></li>
    </ul>
  </nav>
</header>
    </div>

    <div class="sidebar">
        <div class="profile-section">
            <img src="image/logo bleu.jpeg" alt="Logo">
        </div>
        
    </div>

    <!-- [Rest of the HTML remains unchanged] -->
    <div class="dashboard-cards">
        <div class="info-box purchase">
            <div>TOTAL DES ACHATS</div>
            <div><?php echo number_format($metrics['total_purchases'], 2, ',', ' ') . " FCFA"; ?></div>
        </div>
        <div class="info-box sales">
            <div>TOTAL DES VENTES</div>
            <div><?php echo number_format($metrics['total_sales'], 2, ',', ' ') . " FCFA"; ?></div>
        </div>
        <div class="info-box profit">
            <div>BENEFICES</div>
            <div><?php echo number_format($metrics['total_profit'], 2, ',', ' ') . " FCFA"; ?></div>
        </div>
        <div class="info-box count">
            <div>NOMBRES DE VENTES</div>
            <div><?php echo $metrics['sales_count']; ?></div>
        </div>
    </div>
    <div class="chart-container">
        <div style="width: 700px; margin: auto;">
        <canvas id="salesChart"></canvas>
    </div> 
    </div>

    <div class="chart-container">
        <div class="chart-item">
            <canvas id="weeklyChart"></canvas>
        </div>
        <div class="chart-item">
            <canvas id="monthlyChart"></canvas>
        </div>
        <div class="chart-item">
            <canvas id="yearlyChart"></canvas>
        </div>
    </div>

    <div class="task-list">
        <h3>Les 5 dernières ventes</h3>
        <?php if (!empty($recentSales)): ?>
            <table>
                <thead>
                    <tr>
                        <th>Produit</th>
                        <th>Quantité</th>
                        <th>Prix</th>
                        <th>Date de Vente</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($recentSales as $sale): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($sale['nom_pro']); ?></td>
                            <td><?php echo htmlspecialchars($sale['tt_pro']); ?></td>
                            <td><?php echo number_format($sale['montant_total'], 2, ',', ' '); ?> FCFA</td>
                            <td><?php echo htmlspecialchars($sale['date_heure']); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>Aucune vente enregistrée.</p>
        <?php endif; ?>
    </div>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/3.7.0/chart.min.js"></script>
    <script>
         const data = <?php echo $jsonData; ?>;
    
    new Chart(document.getElementById('salesChart'), {
        type: 'line',
        data: {
            labels: data.map(row => row.date),
            datasets: [{
                label: 'Ventes',
                data: data.map(row => row.montant),
                borderColor: '#2563eb',
                tension: 0.1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
        const chartColors = {
            weekly: ['rgba(54, 162, 235, 0.5)', 'rgba(54, 162, 235, 1)'],
            monthly: ['rgba(75, 192, 192, 0.5)', 'rgba(75, 192, 192, 1)'],
            yearly: ['rgba(255, 159, 64, 0.5)', 'rgba(255, 159, 64, 1)']
        };

        const createChart = (elementId, data, label, colors) => {
            new Chart(document.getElementById(elementId), {
                type: 'bar',
                data: {
                    labels: data.labels,
                    datasets: [{
                        label: label,
                        data: data.values,
                        backgroundColor: colors[0],
                        borderColor: colors[1],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });
        };

        createChart('weeklyChart', 
            <?php echo json_encode($chartData['weekly']); ?>, 
            'Ventes de la semaine', 
            chartColors.weekly
        );

        createChart('monthlyChart', 
            <?php echo json_encode($chartData['monthly']); ?>, 
            'Ventes du mois', 
            chartColors.monthly
        );

        createChart('yearlyChart', 
            <?php echo json_encode($chartData['yearly']); ?>, 
            'Ventes de l\'année', 
            chartColors.yearly
        );

        setInterval(() => window.location.reload(), 10000);
    </script>
</body>
</html>