<?php

session_start();
// Database Connection
include 'db_connect.php';

// Requête pour obtenir les données des produits
$query = "
    SELECT 
        p.id,
        p.name,
        p.barcode,
        p.stock,
        COALESCE(SUM(v.tt_pro), 0) as quantite_vendue,
        p.stock - COALESCE(SUM(v.tt_pro), 0) as stock_actuel,
        CASE 
            WHEN (p.stock - COALESCE(SUM(v.tt_pro), 0)) <= (p.stock * 0.3) 
            THEN 1 
            ELSE 0 
        END as alerte
    FROM 
        products p
    LEFT JOIN 
        ventes v ON p.id = v.id
    GROUP BY 
        p.id, p.name, p.barcode, p.stock
";

$result = mysqli_query($conn, $query);

// Vérification des erreurs de requête
if (!$result) {
    die("Erreur de requête: " . mysqli_error($conn));
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Gestion des Stocks</title>
    <style>
        table {
            width: 100%;
            border-collapse: collapse;
            margin: 20px 0;
        }
        th, td {
            border: 1px solid #ddd;
            padding: 8px;
            text-align: left;
        }
        th {
            background-color: #f2f2f2;
        }
        .alert {
            background-color: #ffebee;
        }
        .warning-message {
            background-color: #f44336;
            color: white;
            padding: 10px;
            margin: 10px 0;
            border-radius: 4px;
        }
    </style>
</head>
<body>
    <h1>État des Stocks</h1>
    
    <table>
        <thead>
            <tr>
                <th>Code Barre</th>
                <th>Nom du Produit</th>
                <th>Stock Initial</th>
                <th>Quantité Vendue</th>
                <th>Stock Actuel</th>
                <th>État</th>
            </tr>
        </thead>
        <tbody>
            <?php while ($row = mysqli_fetch_assoc($result)) : ?>
                <tr class="<?php echo $row['alerte'] ? 'alert' : ''; ?>">
                    <td><?php echo htmlspecialchars($row['barcode']); ?></td>
                    <td><?php echo htmlspecialchars($row['name']); ?></td>
                    <td><?php echo $row['stock']; ?></td>
                    <td><?php echo $row['quantite_vendue']; ?></td>
                    <td><?php echo $row['stock_actuel']; ?></td>
                    <td>
                        <?php if ($row['alerte']) : ?>
                            <div class="warning-message">
                                ATTENTION : Stock critique (< 30%)
                            </div>
                        <?php else : ?>
                            Stock normal
                        <?php endif; ?>
                    </td>
                </tr>
            <?php endwhile; ?>
        </tbody>
    </table>

    <?php
    // Fermeture de la connexion
    mysqli_close($conn);
    ?>
</body>
</html>