<?php



session_start();
include 'db_connect.php';

// Fonction pour nettoyer les entrées
function clean_input($data) {
    global $conn;
    return mysqli_real_escape_string($conn, htmlspecialchars(trim($data)));
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Administration - Supermarché</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #ecf0f1;
        }

        body {
            background-color: var(--secondary-color);
            font-family: 'Segoe UI', sans-serif;
        }

        .dashboard {
            padding: 2rem;
        }

        .card {
            border: none;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            margin-bottom: 2rem;
        }

        .card-header {
            background-color: var(--primary-color);
            color: white;
            border-radius: 10px 10px 0 0;
            padding: 1rem;
        }

        .filter-section {
            background-color: white;
            padding: 1rem;
            border-radius: 10px;
            margin-bottom: 2rem;
        }

        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
        }

        th {
            background-color: var(--primary-color);
            color: white;
            padding: 1rem;
        }

        td {
            padding: 1rem;
            border-bottom: 1px solid #ddd;
        }

        tr:hover {
            background-color: #f5f6fa;
        }

        .btn-primary {
            background-color: var(--primary-color);
            border: none;
        }

        .btn-primary:hover {
            background-color: #34495e;
        }
    </style>
</head>
<body>
    <div class="dashboard">
        <div class="card">
            
            <div class="card-body">
                <div class="filter-section">
                    <form id="filterForm" class="row g-3 align-items-end">
                        <div class="col-md-3">
                            <label class="form-label">Type de bilan</label>
                            <select class="form-select" id="bilanType">
                                <option value="ventes">Total ventes</option>
                                <option value="produits">Total produits</option>
                                <option value="commandes">Total commandes</option>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label class="form-label">Date début</label>
                            <input type="date" class="form-control" id="dateDebut">
                        </div>
                        <div class="col-md-3">
                            <label class="form-label">Date fin</label>
                            <input type="date" class="form-control" id="dateFin">
                        </div>
                        <div class="col-md-3">
                            <button type="submit" class="btn btn-primary w-100">Filtrer</button>
                        </div>
                    </form>
                </div>

                <!-- Tableaux -->
                <div id="ventesTable" class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Utilisateur</th>
                                <th>Produit</th>
                                <th>Prix</th>
                                <th>Quantité</th>
                                <th>moyen de paiement</th>
                                <th>Date</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            $query = "SELECT * FROM ventes";
                            $result = mysqli_query($conn, $query);
                            while($row = mysqli_fetch_assoc($result)) {
                                echo "<tr>";
                                echo "<td>".$row['utilisateur_id']."</td>";
                                echo "<td>".$row['montant_total']."</td>";
                                echo "<td>".$row['montant_recu']." FCFA</td>";
                                echo "<td>".$row['monnaie_rendue']."</td>";
                                echo "<td>".$row['moyen_paiement']."</td>";
                                echo "<td>".$row['date_heure']."</td>";
                                echo "</tr>";
                            }
                            ?>
                        </tbody>
                    </table>
                </div>

                <div id="produitsTable" class="table-responsive" style="display: none;">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Produit</th>
                                <th>Quantité</th>
                                <th>Prix</th>
                                <th>Categorie</th>
                                <th>Date</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            $query = "SELECT * FROM products";
                            $result = mysqli_query($conn, $query);
                            while($row = mysqli_fetch_assoc($result)) {
                                echo "<tr>";
                                echo "<td>".$row['name']."</td>";
                                echo "<td>".$row['stock']."</td>";
                                echo "<td>".$row['price']." €</td>";
                                echo "<td>".$row['category']."</td>";
                                echo "<td>".$row['created_at']."</td>";
                                echo "</tr>";
                            }
                            ?>
                        </tbody>
                    </table>
                </div>

                <div id="commandesTable" class="table-responsive" style="display: none;">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Client</th>
                                <th>Produit</th>
                                <th>Quantité</th>
                                <th>Prix</th>
                                <th>Date</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            $query = "SELECT * FROM commandes";
                            $result = mysqli_query($conn, $query);
                            while($row = mysqli_fetch_assoc($result)) {
                                echo "<tr>";
                                echo "<td>".$row['client']."</td>";
                                echo "<td>".$row['produit']."</td>";
                                echo "<td>".$row['quantite']." €</td>";
                                echo "<td>".$row['prix']."</td>";
                                echo "<td>".$row['date_creation']."</td>";
                                echo "</tr>";
                            }
                            ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            // Gestion du changement de type de bilan
            $('#bilanType').change(function() {
                $('.table-responsive').hide();
                switch($(this).val()) {
                    case 'ventes':
                        $('#ventesTable').show();
                        break;
                    case 'produits':
                        $('#produitsTable').show();
                        break;
                    case 'commandes':
                        $('#commandesTable').show();
                        break;
                }
            });

            // Gestion du filtre par date
            $('#filterForm').submit(function(e) {
                e.preventDefault();
                
                let dateDebut = $('#dateDebut').val();
                let dateFin = $('#dateFin').val();
                let type = $('#bilanType').val();

                $.ajax({
                    url: 'filter.php',
                    method: 'POST',
                    data: {
                        dateDebut: dateDebut,
                        dateFin: dateFin,
                        type: type
                    },
                    success: function(response) {
                        $(`#${type}Table tbody`).html(response);
                    },
                    error: function(xhr, status, error) {
                        console.error('Erreur:', error);
                        alert('Une erreur est survenue lors du filtrage des données.');
                    }
                });
            });
        });
    </script>
</body>
</html>