<?php
session_start();
include 'db_connect.php';

// Si requête AJAX pour mettre à jour
if (isset($_GET['action']) && $_GET['action'] == 'update') {
    $query = "SELECT * FROM product_profits ORDER BY id DESC";
    $result = $conn->query($query);

    if (!$result) {
        http_response_code(500);
        echo "Erreur : " . $conn->error;
        exit;
    }

    while ($row = $result->fetch_assoc()) {
        echo "<tr>";
        echo "<td>" . htmlspecialchars($row['product_ref']) . "</td>";
        echo "<td>" . htmlspecialchars($row['product_name']) . "</td>";
        echo "<td>" . number_format($row['selling_price'], 2) . " fcfa</td>";
        echo "<td>" . number_format($row['purchase_price'], 2) . " fcfa</td>";
        echo "<td class='" . ($row['profit'] >= 0 ? 'profit-positive' : 'profit-negative') . "'>";
        echo number_format($row['profit'], 2) . " fcfa</td>";
        echo "</tr>";
    }
    exit;
}

// Fonction pour générer une référence produit unique
function generateRef($productName)
{
    $prefix = strtoupper(substr($productName, 0, 2));
    $random = str_pad(rand(0, 999999), 6, '0', STR_PAD_LEFT);
    return $prefix . $random;
}

// Traitement initial : Vérification et insertion des produits
$query = "SELECT p.name, p.price, c.prix 
          FROM products p 
          LEFT JOIN commandes c ON p.id = c.id";
$result = $conn->query($query);

if ($result) {
    while ($row = $result->fetch_assoc()) {
        // Vérifiez si les clés existent
        if (isset($row['name'], $row['price'], $row['prix'])) {
            // Vérifier si le produit existe déjà
            $checkQuery = "SELECT product_ref FROM product_profits WHERE product_name = ?";
            $stmt = $conn->prepare($checkQuery);

            if (!$stmt) {
                die("Erreur de préparation de la requête : " . $conn->error);
            }

            $stmt->bind_param("s", $row['name']);
            $stmt->execute();
            $stmt->store_result();

            if ($stmt->num_rows == 0) { // Si le produit n'existe pas, insérer
                $ref = generateRef($row['name']);
                $profit = $row['price'] - $row['prix'];

                $insert = "INSERT INTO product_profits 
                           (product_ref, product_name, selling_price, purchase_price, profit)
                           VALUES (?, ?, ?, ?, ?)";
                $stmt = $conn->prepare($insert);

                if (!$stmt) {
                    die("Erreur de préparation de la requête : " . $conn->error);
                }

                $stmt->bind_param("ssddd", $ref, $row['name'], $row['price'], $row['prix'], $profit);
                $stmt->execute();
            }
        } else {
            // Log si les données sont manquantes
            error_log("Données manquantes pour un produit : " . json_encode($row));
        }
    }
} else {
    die("Erreur SQL : " . $conn->error);
}



// Récupérer l'ID de l'utilisateur connecté depuis la session
$user_id = $_SESSION['user_id'];

// Requête SQL pour récupérer les informations de l'utilisateur
$sql = "SELECT username, email FROM employes WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();

// Vérifier si les données de l'utilisateur existent
$employe = $result->fetch_assoc();



// Requête pour calculer la somme de (quantite * prix)
$sql = "SELECT SUM(quantite * prix) AS total FROM commandes";
$result = $conn->query($sql);

// Vérification du résultat
if ($result->num_rows > 0) {
    // Récupération de la valeur totale
    $row = $result->fetch_assoc();
    $total = $row['total'];
} else {
    $total = 0;
}
// Requête pour calculer le total des ventes (quantite * prix)
$sql = "SELECT SUM(stock * price) AS total_ventes FROM products";
$result = $conn->query($sql);

// Vérification du résultat
if ($result->num_rows > 0) {
    // Récupération de la valeur totale des ventes
    $row = $result->fetch_assoc();
    $total_ventes = $row['total_ventes'];
} else {
    $total_ventes = 0;
}
// Requête pour calculer le bénéfice en liant les tables commandes et products
$sql = "SELECT SUM(c.quantite * (p.price - c.prix)) AS total_benefice 
        FROM commandes c
        JOIN products p ON c.id = p.id";
$result = $conn->query($sql);

// Vérification du résultat
if ($result->num_rows > 0) {
    // Récupération de la valeur totale du bénéfice
    $row = $result->fetch_assoc();
    $total_benefice = $row['total_benefice'];
} else {
    $total_benefice = 0;
}
// Requête pour calculer le nombre de ventes selon le nombre de dates enregistrées
$sql = "SELECT COUNT(DISTINCT date_heure) AS nombre_ventes FROM ventes";
$result = $conn->query($sql);

// Vérification du résultat
if ($result->num_rows > 0) {
    // Récupération du nombre total de ventes
    $row = $result->fetch_assoc();
    $nombre_ventes = $row['nombre_ventes'];
} else {
    $nombre_ventes = 0;
}


?>
<!DOCTYPE html>
<html>
<head>
    <title>Gestion des Produits</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <style>
        table { 
            border-collapse: collapse; 
            width: 100%;
            margin-top: 20px;
        }
        th, td { 
            border: 1px solid #ddd; 
            padding: 8px; 
            text-align: left; 
        }
        th { 
            background-color: #f2f2f2;
            position: sticky;
            top: 0;
        }
        .profit-positive { color: green; }
        .profit-negative { color: red; }
          :root {
            --pink: #E91E63;
            --cyan: #00BCD4;
            --green: #8BC34A;
            --orange: #FF9800;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Roboto', sans-serif;
            background: #f5f5f5;
        }

        .top-bar {
            background: #F44336;
            color: white;
            padding: 10px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo-space {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .logo-space img {
    width: 40px;
    height: 40px;
    margin-left: 4cm; /* Déplace le logo vers la droite de 5 cm */
}

        .sidebar {
            width: 250px;
            background: #2196F3;  /* Changé en bleu */
            height: calc(100vh - 60px);
            position: fixed;
            left: 0;
            box-shadow: 2px 0 5px rgba(0,0,0,0.1);
            color: white;
        }

        .profile-section {
            background: linear-gradient(45deg, #EC407A, #D81B60);
            color: white;
            padding: 20px;
            height: 150px;
        }

        .main-navigation {
            padding: 10px;
        }

        .nav-item {
            padding: 12px 15px;
            display: flex;
            align-items: center;
            cursor: pointer;
        }

        .nav-item:hover {
            background: rgba(255, 255, 255, 0.1);
        }

        .dashboard-cards {
            margin-left: 300px;
            padding: 20px;
            display: grid;
            grid-template-columns: repeat(4, 1fr);
            gap: 20px;
        }

        .info-box {
            height: 80px;
            display: flex;
            align-items: center;
            padding: 20px;
            color: white;
            border-radius: 2px;
        }

        .info-box.pink { background: var(--pink); }
        .info-box.cyan { background: var(--cyan); }
        .info-box.green { background: var(--green); }
        .info-box.orange { background: var(--orange); }

        .info-box-number {
            font-size: 26px;
            font-weight: bold;
        }

        .cpu-chart {
            margin: 20px;
            margin-left: 320px;
            background: white;
            padding: 20px;
            border-radius: 2px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }

        .stats-grid {
            margin-left: 320px;
            padding: 0 20px;
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 20px;
        }


        .stats-card {
            background: white;
            padding: 20px;
            border-radius: 2px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }

        .social-trends {
            background: var(--cyan);
            color: white;
        }

        .task-list {
            margin-top: 20px;
            padding: 20px;
            margin-left: 320px;
            background: white;
            border-radius: 2px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        
        .status-badge {
            padding: 3px 8px;
            border-radius: 3px;
            background: #4CAF50;
            color: white;
            font-size: 12px;
        }

        .progress-bar {
            height: 20px;
            background: #4CAF50;
            border-radius: 3px;
        }
         .chart-container {
            display: flex;
            flex-direction: row;
            width: 100%;
            height: 350px; /* Hauteur fixe pour tous les graphiques */
            gap: 15px; /* Espace entre les graphiques */
            padding: 15px;
            box-sizing: border-box;
        }
        .chart-item {
            flex: 1;
            min-width: 0; /* Empêche le débordement */
            height: 100%;
            background-color: white;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        .task-list {
    padding: 20px;
    background: #fff;
    border-radius: 10px;
    box-shadow: 0 10px 20px rgba(0,0,0,0.1);
}

.task-list table {
    width: 100%;
    border-collapse: separate;
    border-spacing: 0;
}

.task-list th {
    background: #2196F3;
    color: white;
    padding: 12px;
    text-align: center;
}

.task-list td {
    padding: 10px;
    text-align: center;
    border-bottom: 1px solid #eee;
}

.task-list tbody tr:hover {
    background: #f5f5f5;
    transform: translateY(-2px);
    box-shadow: 0 5px 10px rgba(0,0,0,0.1);
    transition: all 0.3s ease;
}
          #employe {
        font-family: 'Arial', sans-serif;
        background: linear-gradient(135deg, #6a11cb, #2575fc);
        color: white;
        padding: 20px;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
        max-width: 400px;
        margin: 20px auto;
    }

    #employe h3 {
        font-size: 1.5em;
        border-bottom: 2px solid white;
        padding-bottom: 10px;
        margin-bottom: 0px;
    }
    :root {
            --cyan: #00BCD4;
            --green: #8BC34A;
            --orange: #FF9800;
            --primary-blue: #2196F3;
        }
        
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        
        body {
            font-family: 'Roboto', Arial, sans-serif;
            background: #f5f5f5;
        }
        
        .top-bar {
            background: var(--primary-blue);
            color: white;
            padding: 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            height: 70px;
        }
        
        .logo-space {
            flex: 1;
            display: flex;
            justify-content: center;
            align-items: center;
            gap: 20px;
        }
        
        .logo-space img {
            width: 40px;
            height: 40px;
        }
        
        .company-name {
            font-weight: bold;
            font-size: 1.5em;
        }
        
        .icons {
            display: flex;
            gap: 20px;
            margin-right: 20px;
        }
        
        .sidebar {
            width: 250px;
            background: var(--primary-blue);
            height: calc(100vh - 70px);
            position: fixed;
            left: 0;
            box-shadow: 2px 0 5px rgba(0,0,0,0.1);
            color: white;
        }
        
        .profile-section {
            background: white;
            padding: 0;
            height: 150px;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        
        .profile-section img {
            max-width: 100%;
            max-height: 100%;
            object-fit: contain;
        }
        
        .nav-item {
            padding: 12px 15px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: background 0.3s;
            text-align: center;
        }
        
        .nav-item:hover {
            background: rgba(255,255,255,0.1);
        }
        
        .dashboard-cards {
            margin-left: 300px;
            padding: 20px;
            display: flex;
            gap: 20px;
            flex-wrap: nowrap;
        }
        
        /* [Rest of the CSS remains unchanged] */
        .info-box {
            flex: 1;
            color: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        
        .info-box.purchase { background: var(--green); }
        .info-box.sales { background: var(--cyan); }
        .info-box.profit { background: var(--green); }
        .info-box.count { background: var(--orange); }
        
        .chart-container {
            margin: 20px 20px 20px 300px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 20px;
        }
        
        .chart-item {
            background: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            height: 300px;
        }
        
        .task-list {
            margin: 20px 20px 20px 300px;
            background: white;
            padding: 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        
        .task-list table {
            width: 100%;
            border-collapse: collapse;
        }
        
        .task-list th, .task-list td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }
        
        .task-list th {
            background: var(--primary-blue);
            color: white;
        }
        
        .task-list tr:hover {
            background: #f5f5f5;
        }
    .menu {
  display: flex;
  gap: 1.5rem;
  list-style: none;
  margin: 0;
  padding: 1rem;
  background-color: transparent; /* Enlever le fond */
  box-shadow: none; /* Enlever l'ombre */
}

.menu-item {
  text-decoration: none;
  color: white;
  font-weight: bold;
  font-size: 0.9rem;
  padding: 0.5rem 1rem;
  transition: color 0.3s ease; /* Transition pour un effet fluide */
}

.menu-item:hover {
  color: orange; /* Applique la couleur orange au survol */
}

    </style>
    <script>
        $(document).ready(function () {
            function updateTable() {
                $.get('?action=update', function (data) {
                    $('#productTable').html(data);
                });
            }

            // Rafraîchir toutes les 5 secondes
            setInterval(updateTable, 5000);
        });

    </script>
</head>
<body>
     <div class="top-bar">
        <header class="header">
  <nav>
    <ul class="menu">
      <li><a class="menu-item" href="administrateur.php">ACCUEIL</a></li>
      <li><a class="menu-item" href="page_fournisseur.php">FOURNISSEURS</a></li>
      <li><a class="menu-item" href="page_produit.php">PRODUITS</a></li>
      <li><a class="menu-item" href="page_commande.php">COMMANDES</a></li>
      <li><a class="menu-item" href="page_utilisateur.php">UTILISATEURS</a></li>
      <li><a class="menu-item" href="benefice_produit.php">VOIR BENEFICES</a></li>
      
      <li><a class="menu-item" href="depense_tt.php">VOIR DEPENSE</a></li>
      <li><a class="menu-item" href="index.php">DECONNEXION</a></li>
    </ul>
  </nav>
</header>
    </div>

    <div class="sidebar">
        <div class="profile-section">
           <div class="profile-section">
            <img src="image/logognimaholding.PNG" alt="Logo">
        </div>
        </div>
        <div class="main-navigation">
            
        </div>
    </div>

    <div class="dashboard-cards">
        <div class="info-box purchase">
            <div>
                <div>TOTAL DES ACHATS</div>
                 <?php echo " " . number_format($total, 2, ',', ' ') . " FCFA"; ?>
            </div>
        </div>
        <div class="info-box cyan">
            <div>
                <div>TOTAL DES VENTES</div>
               <?php echo " " . number_format($total_ventes, 2, ',', ' ') . " FCFA"; ?>
            </div>
        </div>
        <div class="info-box green">
            <div>
                <div>BENEFICES</div>
                 <?php echo " " . number_format($total_benefice, 2, ',', ' ') . " FCFA"; ?>
            </div>
        </div>
        <div class="info-box orange">
            <div>
                <div>NOMBRES DE VENTES</div>
                <?php echo " " . $nombre_ventes; ?>
            </div>
        </div>
    </div>

    <div class="cpu-chart">
         <table>
        <thead>
            <tr>
                <th>Référence</th>
                <th>Produit</th>
                <th>Prix de vente</th>
                <th>Prix d'achat</th>
                <th>Bénéfice</th>
            </tr>
        </thead>
        <tbody id="productTable">
            <?php
            $query = "SELECT * FROM product_profits ORDER BY product_ref DESC";
            $result = $conn->query($query);

            if ($result) {
                while ($row = $result->fetch_assoc()): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['product_ref']) ?></td>
                        <td><?= htmlspecialchars($row['product_name']) ?></td>
                        <td><?= number_format($row['selling_price'], 2) ?> fcfa</td>
                        <td><?= number_format($row['purchase_price'], 2) ?> fcfa</td>
                        <td class="<?= $row['profit'] >= 0 ? 'profit-positive' : 'profit-negative' ?>">
                            <?= number_format($row['profit'], 2) ?> fcfa
                        </td>
                    </tr>
                <?php endwhile;
            } else {
                echo "<tr><td colspan='5'>Erreur SQL : " . $conn->error . "</td></tr>";
            }
            ?>
        </tbody>
    </table>
        <canvas id="cpuChart"></canvas>
    </div>
   
</body>
</html>
