<?php
session_start();
include 'db_connect.php';

// Fonction de sécurité pour éviter les injections SQL
function secure($conn, $str) {
    return mysqli_real_escape_string($conn, $str);
}

// Récupération des totaux avec gestion des erreurs
$totalFournisseurs = 0;
$totalCommandes = 0;
$totalRavitaillements = 0;
$totalProduitsVendus = 0;
$totalProduits = 0;

if ($result = $conn->query("SELECT COUNT(*) as total FROM fournisseurs")) {
    $totalFournisseurs = $result->fetch_assoc()['total'];
}

if ($result = $conn->query("SELECT COUNT(*) as total FROM commandes")) {
    $totalCommandes = $result->fetch_assoc()['total'];
}

if ($result = $conn->query("SELECT COUNT(*) as total FROM ravitaillents")) {
    $totalRavitaillements = $result->fetch_assoc()['total'];
}

if ($result = $conn->query("SELECT SUM(tt_pro) as total FROM ventes")) {
    $row = $result->fetch_assoc();
    $totalProduitsVendus = $row['total'] ?? 0;
}

if ($result = $conn->query("SELECT COUNT(*) as total FROM products")) {
    $totalProduits = $result->fetch_assoc()['total'];
}

// Récupérer la liste des produits avec gestion des erreurs
$search = isset($_GET['search']) ? secure($conn, $_GET['search']) : '';
$sqlProduits = "SELECT 
    p.name, 
    p.stock AS quantite_totale,
    COALESCE(SUM(dv.tt_pro), 0) AS nombre_vendu,
    p.stock - COALESCE(SUM(dv.tt_pro), 0) AS reste
FROM products p
LEFT JOIN ventes dv ON p.id = dv.id
WHERE p.name LIKE '%{$search}%'
GROUP BY p.id, p.name, p.stock";

$resultProduits = $conn->query($sqlProduits);

// Vérifier si la requête a réussi
if (!$resultProduits) {
    die("Erreur dans la requête : " . $conn->error);
}
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des Produits</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
            background-color: #f4f4f9;
        }
        h1, h2 {
            color: #333;
            text-align: center;
        }
        .summary {
            display: flex;
            justify-content: space-around;
            margin-bottom: 20px;
            background-color: #007BFF;
            color: white;
            padding: 15px;
            border-radius: 8px;
            flex-wrap: wrap;
        }
        .summary div {
            margin: 5px 10px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            box-shadow: 0px 0px 10px rgba(0,0,0,0.1);
            background-color: #fff;
            margin-top: 20px;
        }
        table th {
            background-color: #007BFF;
            color: white;
            padding: 10px;
        }
        table td {
            padding: 8px;
            text-align: center;
            border-bottom: 1px solid #ddd;
        }
        table tr:nth-child(even) {
            background-color: #f2f2f2;
        }
        input[type="text"] {
            width: 100%;
            padding: 10px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            box-sizing: border-box;
        }
        .error {
            color: red;
            text-align: center;
            margin: 10px 0;
        }
    </style>
</head>
<body>
    <h1>Gestion des détails Produits</h1>
    
    <div class="summary">
        <div>Total Fournisseurs : <strong><?php echo $totalFournisseurs; ?></strong></div>
        <div>Total Commandes : <strong><?php echo $totalCommandes; ?></strong></div>
        <div>Total Ravitaillements : <strong><?php echo $totalRavitaillements; ?></strong></div>
        <div>Produits Vendus : <strong><?php echo $totalProduitsVendus; ?></strong></div>
        <div>Total Produits : <strong><?php echo $totalProduits; ?></strong></div>
    </div>

    <input type="text" id="search" placeholder="Rechercher un produit..." onkeyup="searchProduct()">

    <div id="productTable">
        <table>
            <thead>
                <tr>
                    <th>Nom du Produit</th>
                    <th>Quantité Totale</th>
                    <th>Nombre Vendu</th>
                    <th>Reste</th>
                </tr>
            </thead>
            <tbody>
                <?php 
                if ($resultProduits && $resultProduits->num_rows > 0) {
                    while ($row = $resultProduits->fetch_assoc()) {
                        echo "<tr>";
                        echo "<td>" . htmlspecialchars($row['name']) . "</td>";
                        echo "<td>" . $row['quantite_totale'] . "</td>";
                        echo "<td>" . $row['nombre_vendu'] . "</td>";
                        echo "<td>" . $row['reste'] . "</td>";
                        echo "</tr>";
                    }
                } else {
                    echo "<tr><td colspan='4'>Aucun produit trouvé</td></tr>";
                }
                ?>
            </tbody>
        </table>
    </div>

    <script>
        function searchProduct() {
            const search = document.getElementById('search').value;
            const xhr = new XMLHttpRequest();
            xhr.open('GET', '?search=' + encodeURIComponent(search), true);
            xhr.onload = function() {
                if (this.status === 200) {
                    const parser = new DOMParser();
                    const doc = parser.parseFromString(this.responseText, 'text/html');
                    document.getElementById('productTable').innerHTML = doc.getElementById('productTable').innerHTML;
                }
            }
            xhr.send();
        }
    </script>
</body>
</html>
<?php
$conn->close();
?>