<?php
// Error handling configuration
ini_set('display_errors', 0);
error_reporting(E_ALL);
ini_set('log_errors', 1);
ini_set('error_log', 'error.log');

// Start session
session_start();

// Database configuration
try {
    $db_host = 'localhost';  // Change this to your production host
    $db_user = 'astechc1_gnimaholding';  // Change this
    $db_pass = '1Q&=$zcNDKZE';  // Change this
    $db_name = 'astechc1_gnimaholding';  // Change this
    
    $conn = new mysqli($db_host, $db_user, $db_pass, $db_name);
    $conn->set_charset("utf8mb4");
    
    if ($conn->connect_error) {
        throw new Exception("Connection failed: " . $conn->connect_error);
    }
} catch (Exception $e) {
    error_log("Database connection error: " . $e->getMessage());
    $conn = null;
}

// Helper functions
function executeQuery($conn, $query) {
    try {
        if (!$conn) {
            throw new Exception("Database connection not available");
        }
        $result = $conn->query($query);
        if (!$result) {
            throw new Exception("Query failed: " . $conn->error);
        }
        return $result;
    } catch (Exception $e) {
        error_log("Query execution error: " . $e->getMessage());
        return false;
    }
}

function getQuerySum($conn, $query) {
    try {
        $result = executeQuery($conn, $query);
        if ($result && $row = $result->fetch_assoc()) {
            return floatval($row['total'] ?? 0);
        }
        return 0;
    } catch (Exception $e) {
        error_log("GetQuerySum error: " . $e->getMessage());
        return 0;
    }
}

// Initialize variables with default values
$total_products = 0;
$total_orders = 0;
$total_profits = 0;
$total_gros = 0;
$total_detail = 0;
$total_ordered = 0;
$total_received = 0;
$monthly_data = [];
$weekly_data = [];

// Fetch data only if database connection is successful
if ($conn) {
    try {
        // Fetch total products amount
        $total_products = getQuerySum($conn, "SELECT SUM(price) as total FROM products");
        
        // Fetch total orders amount
        $total_orders = getQuerySum($conn, "SELECT SUM(total_commande) as total FROM commandes");
        
        // Calculate profits
        $total_profits = $total_orders * 0.2;
        
        // Fetch products by type
        $total_gros = getQuerySum($conn, "SELECT SUM(price) as total FROM products WHERE type='gros'");
        $total_detail = getQuerySum($conn, "SELECT SUM(price) as total FROM products WHERE type='detail'");
        
        // Count orders and products
        $result_ordered = executeQuery($conn, "SELECT COUNT(*) as total FROM commandes");
        $total_ordered = ($result_ordered && $row = $result_ordered->fetch_assoc()) ? intval($row['total']) : 0;
        
        $result_received = executeQuery($conn, "SELECT COUNT(*) as total FROM products");
        $total_received = ($result_received && $row = $result_received->fetch_assoc()) ? intval($row['total']) : 0;
        
        // Monthly sales data
        $query_monthly = "SELECT DATE(date_creation) as date, SUM(total_commande) as total 
                         FROM commandes 
                         WHERE MONTH(date_creation) = MONTH(CURRENT_DATE)
                         GROUP BY DATE(date_creation)";
        $result_monthly = executeQuery($conn, $query_monthly);
        if ($result_monthly) {
            while ($row = $result_monthly->fetch_assoc()) {
                $monthly_data[] = $row;
            }
        }
        
        // Weekly sales data
        $query_weekly = "SELECT DATE(date_creation) as date, SUM(total_commande) as total 
                        FROM commandes 
                        WHERE date_creation >= DATE_SUB(CURRENT_DATE, INTERVAL 7 DAY)
                        GROUP BY DATE(date_creation)";
        $result_weekly = executeQuery($conn, $query_weekly);
        if ($result_weekly) {
            while ($row = $result_weekly->fetch_assoc()) {
                $weekly_data[] = $row;
            }
        }
    } catch (Exception $e) {
        error_log("Data fetching error: " . $e->getMessage());
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/3.7.0/chart.min.js"></script>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            background-color: #f4f4f4;
        }
        .sidebar {
            width: 250px;
            background-color: #001f3f;
            color: #fff;
            height: 100vh;
            position: fixed;
            display: flex;
            flex-direction: column;
            align-items: center;
        }
        .sidebar .logo {
            width: 100%;
            background-color: #003366;
            text-align: center;
            padding: 20px 0;
            font-size: 20px;
            font-weight: bold;
        }
        .sidebar ul {
            list-style: none;
            padding: 0;
            margin: 0;
            width: 100%;
        }
        .sidebar ul li {
            padding: 15px 20px;
            border-bottom: 1px solid rgba(255, 255, 255, 0.2);
            text-align: center;
        }
        .sidebar ul li a {
            color: white;
            text-decoration: none;
            display: block;
        }
        .sidebar ul li:hover {
            background-color: #002b4e;
            cursor: pointer;
        }
        .main-content {
            margin-left: 250px;
            padding: 20px;
        }
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px;
            background-color: #333;
            color: white;
            margin-bottom: 20px;
        }
        .header h2 {
            margin: 0;
        }
        .top-grid {
            display: grid;
            grid-template-columns: repeat(4, 1fr);
            gap: 15px;
            margin-bottom: 20px;
        }
        .bottom-grid {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 15px;
            margin-bottom: 20px;
        }
        .card {
            padding: 20px;
            border-radius: 8px;
            color: white;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            transition: transform 0.2s;
        }
        .card:hover {
            transform: translateY(-5px);
        }
        .blue-bg {
            background: linear-gradient(135deg, #1e88e5, #1565c0);
        }
        .green-bg {
            background: linear-gradient(135deg, #43a047, #2e7d32);
        }
        .orange-bg {
            background: linear-gradient(135deg, #fb8c00, #ef6c00);
        }
        .charts-grid {
            display: grid;
            grid-template-columns: repeat(2, 1fr);
            gap: 20px;
            margin-top: 20px;
        }
        .chart-container {
            background: white;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            height: 400px;
        }
        canvas {
            width: 100% !important;
            height: 100% !important;
        }
        .error-message {
            background-color: #ffebee;
            color: #c62828;
            padding: 10px;
            margin: 10px 0;
            border-radius: 4px;
            display: none;
        }
    </style>
</head>
<body>
    <div class="sidebar">
        <div class="logo-container">
            <img src="image/logognimaholding.PNG" alt="Logo" style="max-width: 100%; max-height: 150%;">
        </div>
        <ul>
            <li><a href="brod_gestionnaire.php">Accueil</a></li>
            <li><a href="page_produit_bon.php">Produits</a></li>
            <li><a href="enregistrer_fournisseur.php">Fournisseurs</a></li>
            <li><a href="enregistrer_commande.php">Commandes</a></li>
            <li><a href="enregistrer_ravitaillements.php">Ravitaillement</a></li>
            <li><a href="#">Tous détail produit</a></li>
            <li><a href="#">Statistiques</a></li>
            <li><a href="index.php">Déconnexion</a></li>
        </ul>
    </div>

    <div class="main-content">
        <div id="errorMessage" class="error-message"></div>
        
        <div class="header">
            <h2>Tableau de bord</h2>
            <div>
                <span>🔔</span>
                <span>⚙</span>
                <span>🔓</span>
            </div>
        </div>

        <div class="top-grid">
            <div class="card blue-bg">
                <h3>Total Produits</h3>
                <p><?php echo number_format($total_products, 2); ?> fcfa</p>
            </div>
            <div class="card green-bg">
                <h3>Total Commandes</h3>
                <p><?php echo number_format($total_orders, 2); ?> fcfa</p>
            </div>
            <div class="card orange-bg">
                <h3>Bénéfices</h3>
                <p><?php echo number_format($total_profits, 2); ?> fcfa</p>
            </div>
            <div class="card blue-bg">
                <h3>Produits Gros</h3>
                <p><?php echo number_format($total_gros, 2); ?> fcfa</p>
            </div>
        </div>

        <div class="bottom-grid">
            <div class="card green-bg">
                <h3>Produits Détail</h3>
                <p><?php echo number_format($total_detail, 2); ?> fcfa</p>
            </div>
            <div class="card orange-bg">
                <h3>Produits Commandés</h3>
                <p><?php echo $total_ordered; ?></p>
            </div>
            <div class="card blue-bg">
                <h3>Produits Reçus</h3>
                <p><?php echo $total_received; ?></p>
            </div>
        </div>

        <div class="charts-grid">
            <div class="chart-container">
                <h3>Ventes du Mois</h3>
                <canvas id="monthlyChart"></canvas>
            </div>
            <div class="chart-container">
                <h3>Ventes Hebdomadaires</h3>
                <canvas id="weeklyChart"></canvas>
            </div>
        </div>
    </div>

    <script>
        // Error handling function
        function showError(message) {
            const errorDiv = document.getElementById('errorMessage');
            if (errorDiv) {
                errorDiv.textContent = message;
                errorDiv.style.display = 'block';
            }
        }

        // Monthly Sales Chart
        try {
            const monthlyCtx = document.getElementById('monthlyChart').getContext('2d');
            new Chart(monthlyCtx, {
                type: 'bar',
                data: {
                    labels: <?php echo json_encode(array_column($monthly_data, 'date')); ?>,
                    datasets: [{
                        label: 'Ventes du mois',
                        data: <?php echo json_encode(array_column($monthly_data, 'total')); ?>,
                        backgroundColor: '#1e88e5',
                        borderRadius: 5
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });
        } catch (error) {
            console.error('Error creating monthly chart:', error);
            showError('Erreur lors de la création du graphique mensuel');
        }

        // Weekly Sales Chart
        try {
            const weeklyCtx = document.getElementById('weeklyChart').getContext('2d');
            new Chart(weeklyCtx, {
                type: 'pie',
                data: {
                    labels: <?php echo json_encode(array_column($weekly_data, 'date')); ?>,
                    datasets: [{
                        data: <?php echo json_encode(array_column($weekly_data, 'total')); ?>,
                        backgroundColor: [
                            '#1e88e5',
                            '#43a047',
                            '#fb8c00',
                            '#e53935',
                            '#8e24aa',
                            '#3949ab',
                            '#00acc1'
                        ]
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });
        } catch (error) {
            console.error('Error creating weekly chart:', error);
            showError('Erreur lors de la création du graphique hebdomadaire');
        }
    </script>
</body>
</html>