<?php
session_start();
// Database Connection
include 'db_connect.php';

// Session simplifiée
$_SESSION['poste'] = 'Caissier';
$_SESSION['user_id'] = 1;

$imagePath = 'image/systeme-point-vent.jpg';
$sales_history = null;
if (isset($_POST['record_sale'])) {
    $sale_data = json_decode($_POST['sale_data'], true);
    
    // Génération du numéro de facture
    $numero_facture = 'FAC-' . date('YmdHis') . '-' . rand(1000, 9999);
    
    // Préparation de la requête d'insertion
    $detail_query = $conn->prepare("
        INSERT INTO details_vente (
            numero_facture,
            code_barre_produit,
            nom_produit,
            quantite,
            prix_unitaire,
            total_produit,
            total_montant,
            date_heure,
            type_produit,
            moyen_paiement,
            montant_recu,
            monnaie
        ) VALUES (?, ?, ?, ?, ?, ?, ?, NOW(), ?, ?, ?, ?)
    ");

    if ($detail_query === false) {
        throw new Exception("Erreur de préparation de la requête details_vente: " . $conn->error);
    }

    // Pour chaque article dans le panier
    foreach ($sale_data['items'] as $item) {
        // Récupération du code-barre et type de produit
        $product_query = $conn->prepare("SELECT barcode, type_pro FROM products WHERE id = ?");
        $product_query->bind_param("i", $item['id']);
        $product_query->execute();
        $product_result = $product_query->get_result();
        $product_data = $product_result->fetch_assoc();
        
        $total_produit = $item['price'] * $item['qty'];
        
        // Insertion des détails pour chaque produit
        $detail_query->bind_param(
            "sssiiddssdd",
            $numero_facture,
            $product_data['barcode'],
            $item['name'],
            $item['qty'],
            $item['price'],
            $total_produit,
            $sale_data['total'],
            $product_data['type_pro'],
            $sale_data['payment_method'],
            $sale_data['montant_recu'],
            $sale_data['monnaie']
        );

        if (!$detail_query->execute()) {
            throw new Exception("Erreur d'insertion des détails: " . $detail_query->error);
        }
    }

    // Continue avec le reste du code existant...
}

try {
    // Enregistrement de la vente
    if (isset($_POST['record_sale'])) {
        $sale_data = json_decode($_POST['sale_data'], true);
        
        // Vérification de la connexion
        if ($conn->connect_error) {
            throw new Exception("Erreur de connexion : " . $conn->connect_error);
        }

        // Préparation des chaînes de produits et quantités
        $product_names = [];
        $product_quantities = [];
        foreach ($sale_data['items'] as $item) {
            $product_names[] = $item['name'];
            $product_quantities[] = $item['qty'];
        }
        $nom_pro = implode(', ', $product_names);
        $tt_pro = implode(', ', $product_quantities);

        // Insertion de la vente avec vérification
        $sale_query = $conn->prepare("
            INSERT INTO ventes (
                utilisateur_id,
                montant_total,
                montant_recu,
                monnaie_rendue,
                moyen_paiement,
                date_heure,
                nom_pro,
                tt_pro
            ) VALUES (?, ?, ?, ?, ?, NOW(), ?, ?)
        ");
        
        if($sale_query === false) {
            throw new Exception("Erreur de préparation de la requête: " . $conn->error);
        }
        
        $sale_query->bind_param(
            "idddsss", 
            $_SESSION['user_id'],
            $sale_data['total'],
            $sale_data['montant_recu'],
            $sale_data['monnaie'],
            $sale_data['payment_method'],
            $nom_pro,
            $tt_pro
        );

        if(!$sale_query->execute()) {
            throw new Exception("Erreur d'exécution de la requête: " . $sale_query->error);
        }

        // Mise à jour du stock avec vérification
        $stock_query = $conn->prepare("UPDATE products SET stock = stock - ? WHERE id = ?");
        if($stock_query === false) {
            throw new Exception("Erreur de préparation de la requête de stock: " . $conn->error);
        }

        foreach ($sale_data['items'] as $item) {
            $stock_query->bind_param("ii", $item['qty'], $item['id']);
            if(!$stock_query->execute()) {
                throw new Exception("Erreur de mise à jour du stock: " . $stock_query->error);
            }
        }

        echo json_encode(['success' => true]);
        exit();
    }

    // Recherche dynamique de produits avec vérification
    if (isset($_GET['search'])) {
        $search = $_GET['search'];
        $query = $conn->prepare("SELECT * FROM products WHERE barcode LIKE ? OR name LIKE ? LIMIT 10");
        if($query === false) {
            throw new Exception("Erreur de préparation de la requête de recherche: " . $conn->error);
        }

        $like_search = "%$search%";
        $query->bind_param("ss", $like_search, $like_search);
        
        if(!$query->execute()) {
            throw new Exception("Erreur d'exécution de la recherche: " . $query->error);
        }

        $result = $query->get_result();
        $products = [];
        while ($row = $result->fetch_assoc()) {
            $products[] = $row;
        }
        echo json_encode($products);
        exit();
    }

    // Historique des ventes avec vérification
    $history_query = $conn->prepare("
        SELECT id, utilisateur_id, montant_total, montant_recu, 
               monnaie_rendue, moyen_paiement, date_heure,
               nom_pro, tt_pro
        FROM ventes 
        ORDER BY date_heure DESC 
        LIMIT 50
    ");
    
    if($history_query === false) {
        throw new Exception("Erreur de préparation de la requête d'historique: " . $conn->error);
    }

    if(!$history_query->execute()) {
        throw new Exception("Erreur d'exécution de la requête d'historique: " . $history_query->error);
    }

    $sales_history = $history_query->get_result();

} catch (Exception $e) {
    error_log($e->getMessage());
    if (isset($_GET['search']) || isset($_POST['record_sale'])) {
        echo json_encode(['error' => $e->getMessage()]);
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>BADIE SERVICES - Gestion des Ventes</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/quagga@0.12.1/dist/quagga.min.js"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body {
            margin: 0;
            padding: 0;
            background-image: url('<?php echo $imagePath; ?>');
            background-size: cover;
            background-position: center;
            background-repeat: no-repeat;
            height: 100vh;
        }
        @media print {
            body * {
                visibility: hidden;
            }
            #receipt-for-print, #receipt-for-print * {
                visibility: visible;
            }
            #receipt-for-print {
                position: absolute;
                left: 0;
                top: 0;
                width: 80mm;
                margin: 0;
                padding: 0;
            }
        }
        .sale-details {
            display: none;
            background-color: #f8f9fa;
            padding: 1rem;
            margin-top: 0.5rem;
            border-radius: 0.25rem;
        }
        .toggle-details {
            cursor: pointer;
            color: #4a5568;
        }
        .toggle-details:hover {
            color: #2d3748;
        }
    </style>
</head>
<body class="bg-gray-100">
    <!-- [Le reste du HTML reste inchangé, continué dans la prochaine partie] -->
    <header class="bg-blue-600 text-white flex items-center justify-between p-4">
        <div class="flex items-center">
            <h1 class="text-2xl font-bold mr-4">GNIMA HOLDING</h1>
            <button onclick="window.location.href = 'index.php'" class="bg-red-500 hover:bg-red-600 px-3 py-1 rounded">
                Déconnexion
            </button>
        </div>
        <div class="text-center">
            
            <p onclick="window.location.href = 'page_caisse.php'"> Retour</p>
        </div>

        <div class="text-center">
            
            <p id="current-user" class="text-xl"> <?php echo htmlspecialchars($_SESSION['poste']); ?></p>
            <p id="current-datetime" class="text-sm"></p>
        </div>
    </header>

    <div class="container mx-auto grid grid-cols-3 gap-4 p-4">
        <!-- Section Vente -->
        <div class="col-span-2 bg-white p-4 rounded shadow">
            <h2 class="text-2xl mb-4">Gestion des Ventes</h2>
            
            <!-- Recherche et Scanner -->
            <div class="flex mb-4">
                <input 
                    type="text" 
                    id="search" 
                    placeholder="Rechercher un produit (nom/code-barres)"
                    class="flex-grow p-2 border rounded mr-2"
                >
                <button 
                    id="scan-barcode" 
                    class="bg-green-500 text-white px-4 py-2 rounded"
                >
                    Scanner
                </button>
            </div>

            <!-- Zone Scanner -->
            <div id="scanner-container" style="display:none; width:100%;">
                <div id="scanner" class="w-full h-64"></div>
            </div>

            <!-- Résultats -->
            <table id="results" class="w-full mb-4">
                <thead>
                    <tr class="bg-gray-200">
                        <th>Code Barre</th>
                        <th>Nom</th>
                        <th>Prix</th>
                        
                        <th>Quantité</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody></tbody>
            </table>

            <!-- Panier -->
            <h3 class="text-xl mb-2">Panier</h3>
            <table id="cart" class="w-full mb-4">
                <thead>
                    <tr class="bg-gray-200">
                        <th>Nom</th>
                        <th>Quantité</th>
                        <th>Prix Unitaire</th>
                        <th>Montant</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody></tbody>
            </table>

            <!-- Détails des produits -->
            <div id="product-details" class="mt-4 mb-4">
                <!-- Les détails des produits seront insérés ici dynamiquement -->
            </div>

            <div class="flex justify-between items-center">
                <div>
                    <strong>Total : </strong> 
                    <span id="total">0</span> FCFA
                </div>
                <select id="moyenPaiement" class="p-2 border rounded">
                    <option value="Espèce">Espèce</option>
                    <option value="Carte">Carte</option>
                    <option value="Mobile Money">Mobile Money</option>
                </select>
                <button 
                    onclick="validateSale()" 
                    class="bg-blue-500 text-white px-4 py-2 rounded"
                >
                    Régler la facture
                </button>
            </div>
        </div>

        <!-- Historique -->
        <div class="bg-white p-4 rounded shadow overflow-y-auto max-h-screen">
            <h2 class="text-2xl mb-4">Historique des Ventes</h2>
            <div class="space-y-2">
                <?php 
                if($sales_history !== null) {
                    while($sale = $sales_history->fetch_assoc()): 
                        $sale_id = $sale['id'];
                ?>
                    <div class="border-b pb-2">
                        <div class="flex justify-between items-center cursor-pointer" onclick="toggleSaleDetails(<?= $sale_id ?>)">
                            <div class="flex items-center space-x-2">
                                <i class="fas fa-ellipsis-h toggle-details"></i>
                                <span><?= htmlspecialchars($sale['date_heure']) ?></span>
                            </div>
                            <span><?= number_format($sale['montant_total'], 2) ?> FCFA</span>
                        </div>
                        <div id="sale-<?= $sale_id ?>" class="sale-details">
                            <div class="grid grid-cols-2 gap-4">
                                <div>
                                    <p class="font-semibold">Montant reçu:</p>
                                    <p><?= number_format($sale['montant_recu'], 2) ?> FCFA</p>
                                </div>
                                <div>
                                    <p class="font-semibold">Monnaie rendue:</p>
                                    <p><?= number_format($sale['monnaie_rendue'], 2) ?> FCFA</p>
                                </div>
                                <div>
                                    <p class="font-semibold">Mode de paiement:</p>
                                    <p><?= htmlspecialchars($sale['moyen_paiement']) ?></p>
                                </div>
                            </div>
                            <div class="mt-4">
                                <p class="font-semibold mb-2">Produits achetés:</p>
                                <?php
                                $products = explode(', ', $sale['nom_pro']);
                                $quantities = explode(', ', $sale['tt_pro']);
                                for($i = 0; $i < count($products); $i++):
                                ?>
                                    <div class="bg-gray-50 p-2 rounded mb-2">
                                        <p>Produit: <?= htmlspecialchars($products[$i]) ?></p>
                                        <p>Quantité: <?= htmlspecialchars($quantities[$i]) ?></p>
                                    </div>
                                <?php endfor; ?>
                            </div>
                        </div>
                    </div>
                <?php 
                    endwhile;
                } 
                ?>
            </div>
        </div>
    </div>

<script>
let cart = [];

// Mise à jour date/heure
function updateDateTime() {
    const now = new Date();
    document.getElementById('current-datetime').textContent = 
        now.toLocaleDateString() + ' ' + now.toLocaleTimeString();
}
setInterval(updateDateTime, 1000);
updateDateTime();

// Scanner Code-barres
$("#scan-barcode").click(function() {
    $("#scanner-container").toggle();
    if ($("#scanner-container").is(":visible")) {
        Quagga.init({
            inputStream : {
                name : "Live",
                type : "LiveStream",
                target: document.querySelector('#scanner')
            },
            decoder : {
                readers : ["ean_reader", "ean_8_reader", "code_128_reader"]
            }
        }, function(err) {
            if (err) {
                console.log(err);
                return;
            }
            Quagga.start();
        });

        Quagga.onDetected(function(result) {
            const code = result.codeResult.code;
            $("#search").val(code);
            $("#search").trigger('input');
            Quagga.stop();
            $("#scanner-container").hide();
        });
    } else {
        Quagga.stop();
    }
});

// Recherche dynamique
$("#search").on("input", function() {
    const searchTerm = $(this).val();
      if (searchTerm.length > 0) {
        $.ajax({
            url: '',
            method: 'GET',
            data: { search: searchTerm },
            dataType: 'json',
            success: function(products) {
                let html = products.map(p => `
                    <tr>
                        <td>${p.barcode}</td>
                        <td>${p.name}</td>
                        <td>${p.price}</td>
                        
                        <td>
                            <input 
                                type="number" 
                                min="1" 
                                max="${p.stock}" 
                                value="1" 
                                id="qty_${p.id}" 
                                class="w-20 p-1 border rounded"
                            >
                        </td>
                        <td>
                            <button 
                                onclick="addToCart(${p.id}, '${p.name}', ${p.price}, $('#qty_${p.id}').val())" 
                                class="bg-green-500 text-white px-2 py-1 rounded"
                            >
                                Ajouter
                            </button>
                        </td>
                    </tr>
                `).join('');
                $("#results tbody").html(html);
            },
            error: function(xhr, status, error) {
                console.error("Erreur de recherche:", error);
                alert("Erreur lors de la recherche de produits");
            }
        });
    } else {
        $("#results tbody").html('');
    }
});

// Ajout au panier
function addToCart(id, name, price, qty) {
    qty = parseInt(qty);
    cart.push({ 
        id, 
        name, 
        price, 
        qty,
        timestamp: new Date().toLocaleString() 
    });
    
    updateCart();
    $("#search").val('');
    $("#results tbody").html('');
    displayProductDetails();
}

// Affichage des détails des produits
function displayProductDetails() {
    let detailsHtml = cart.map((item, index) => {
        let montant = item.qty * item.price;
        return `
            <div class="bg-gray-100 p-4 mb-2 rounded">
                <h4 class="font-bold">Détails du produit #${index + 1}</h4>
                <p>Nom: ${item.name}</p>
                <p>Qte: ${item.qty}</p>
                <p>Pu: ${item.price.toFixed(2)} FCFA</p>
                <p>Mtt: ${montant.toFixed(2)} FCFA</p>
                <p>Heure: ${item.timestamp}</p>
            </div>
        `;
    }).join('');
    
    $("#product-details").html(detailsHtml);
}

// Mise à jour du panier
function updateCart() {
    let total = 0;
    let html = cart.map((item, index) => {
        let montant = item.qty * item.price;
        total += montant;
        return `
            <tr>
                <td>${item.name}</td>
                <td>${item.qty}</td>
                <td>${item.price.toFixed(2)}</td>
                <td>${montant.toFixed(2)}</td>
                <td>
                    <button 
                        onclick="removeFromCart(${index})" 
                        class="bg-red-500 text-white px-2 py-1 rounded"
                    >
                        Supprimer
                    </button>
                </td>
            </tr>
        `;
    }).join('');

    $("#cart tbody").html(html);
    $("#total").text(total.toFixed(2));
}

// Suppression du panier
function removeFromCart(index) {
    cart.splice(index, 1);
    updateCart();
    displayProductDetails();
}

// Validation de la vente
function validateSale() {
    if (cart.length === 0) {
        alert("Le panier est vide !");
        return;
    }

    let total = parseFloat($("#total").text());
    let montantRecu = parseFloat(prompt("Entrez le montant reçu :"));
    
    if (isNaN(montantRecu) || montantRecu < total) {
        alert("Montant invalide ou insuffisant !");
        return;
    }
    
    let monnaie = (montantRecu - total).toFixed(2);
    let paymentMethod = $("#moyenPaiement").val();
    let currentDate = new Date();

    let receiptHtml = `
        <div class="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center" id="receipt-modal">
            <div class="bg-white p-6 max-w-md mx-auto rounded-lg shadow-xl">
                <div id="receipt-for-print" class="bg-white p-4" style="width: 80mm; margin: auto;">
                    <div class="text-center mb-4">
                        <h2 class="text-xl font-bold">BADIE SERVICES</h2>
                        <p class="text-sm">Reçu de vente</p>
                        <p class="text-sm">${currentDate.toLocaleString()}</p>
                    </div>
                    
                    <div class="border-t border-b py-2 my-2">
                        <div class="flex justify-between">
                            <span>N° Facture:</span>
                            <span>${Math.floor(Math.random() * 1000000)}</span>
                        </div>
                        <div class="flex justify-between">
                            <span>Caissier:</span>
                            <span>${document.getElementById('current-user').textContent.split(': ')[1]}</span>
                        </div>
                    </div>
                    
                    <div class="my-4">
                        <h3 class="font-bold mb-2">Articles:</h3>
                        ${cart.map(item => `
                            <div class="border-b py-1">
                                <div class="flex justify-between">
                                    <span>${item.name}</span>
                                    <span>${item.qty}x</span>
                                </div>
                                <div class="flex justify-between text-sm">
                                    <span>PU: ${item.price.toFixed(2)} FCFA</span>
                                    <span>${(item.price * item.qty).toFixed(2)} FCFA</span>
                                </div>
                            </div>
                        `).join('')}
                    </div>
                    
                    <div class="border-t pt-2">
                        <div class="flex justify-between font-bold">
                            <span>TOTAL:</span>
                            <span>${total.toFixed(2)} FCFA</span>
                        </div>
                        <div class="flex justify-between">
                            <span>Montant reçu:</span>
                            <span>${montantRecu.toFixed(2)} FCFA</span>
                        </div>
                        <div class="flex justify-between">
                            <span>Monnaie rendue:</span>
                            <span>${monnaie} FCFA</span>
                        </div>
                        <div class="flex justify-between">
                            <span>Mode de paiement:</span>
                            <span>${paymentMethod}</span>
                        </div>
                    </div>
                    
                    <div class="text-center mt-4 text-sm">
                        <p>Merci de votre confiance!</p>
                        <p>À bientôt</p>
                    </div>
                </div>
                
                <div class="flex justify-center space-x-4 mt-6">
                    <button onclick="printReceipt()" class="bg-blue-500 hover:bg-blue-600 text-white px-6 py-2 rounded">
                        Imprimer
                    </button>
                    <button onclick="closeReceipt()" class="bg-gray-500 hover:bg-gray-600 text-white px-6 py-2 rounded">
                        Fermer
                    </button>
                </div>
            </div>
        </div>
    `;

    document.body.insertAdjacentHTML('beforeend', receiptHtml);
    
    // Save sale data to be used later
    window.saleData = {
        total: total,
        montant_recu: montantRecu,
        monnaie: monnaie,
        payment_method: paymentMethod,
        items: cart
    };
}

// Fonction pour imprimer le reçu
function printReceipt() {
    const printContent = document.getElementById('receipt-for-print').innerHTML;
    const printWindow = window.open('', '', 'height=600,width=800');
    printWindow.document.write('<html><head><title>Reçu - BADIE SERVICES</title>');
    printWindow.document.write('<link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">');
    printWindow.document.write('<style>@media print { body { width: 80mm; margin: 0; padding: 0; } }</style>');
    printWindow.document.write('</head><body>');
    printWindow.document.write('<div style="width: 80mm; padding: 10px;">');
    printWindow.document.write(printContent);
    printWindow.document.write('</div></body></html>');
    
    setTimeout(() => {
        printWindow.print();
        printWindow.close();
    }, 500);
}

// Fonction pour fermer le reçu
function closeReceipt() {
    const receiptModal = document.getElementById('receipt-modal');
    if (receiptModal) {
        receiptModal.remove();
        
        // Use the saved sale data
        if (window.saleData) {
            $.ajax({
                url: '',
                method: 'POST',
                data: {
                    record_sale: true,
                    sale_data: JSON.stringify(window.saleData)
                },
                success: function(response) {
                    try {
                        let result = JSON.parse(response);
                        if (result.success) {
                            cart = [];
                            updateCart();
                            displayProductDetails();
                            window.saleData = null; // Clear the saved data
                            location.reload();
                        } else {
                            throw new Error('Erreur lors de l\'enregistrement');
                        }
                    } catch (e) {
                        console.error(e);
                        alert("Erreur lors de l'enregistrement de la vente. Veuillez réessayer.");
                    }
                },
                error: function(xhr, status, error) {
                    alert("Erreur lors de l'enregistrement de la vente. Veuillez réessayer.");
                    console.error(error);
                }
            });
        }
    }
}

// Fonction pour basculer l'affichage des détails d'une vente
function toggleSaleDetails(saleId) {
    const detailsDiv = document.getElementById(`sale-${saleId}`);
    if (detailsDiv.style.display === 'none' || !detailsDiv.style.display) {
        detailsDiv.style.display = 'block';
    } else {
        detailsDiv.style.display = 'none';
    }
}

// Empêcher la soumission du formulaire sur appui de la touche Entrée
$(document).on('keypress', 'input', function(e) {
    if (e.which == 13) {
        e.preventDefault();
    }
});
</script>
</body>
</html>