<?php
session_start();
include 'db_connect.php';

// Générer un nouveau token si non existant
if (!isset($_SESSION['form_token'])) {
    $_SESSION['form_token'] = bin2hex(random_bytes(32));
}

// Traitement du formulaire
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Vérifier si le token est valide
    if (isset($_POST['token']) && $_POST['token'] === $_SESSION['form_token']) {
        $datedep = mysqli_real_escape_string($conn, $_POST['datedep']);
        $libelle = mysqli_real_escape_string($conn, $_POST['libelle']);
        $montant = mysqli_real_escape_string($conn, $_POST['montant']);
        $magasin = mysqli_real_escape_string($conn, $_POST['magasin']);
        
        $sql = "INSERT INTO magasindep (datedep, libelle, montant, magasin) 
                VALUES ('$datedep', '$libelle', '$montant', '$magasin')";
        
        if (mysqli_query($conn, $sql)) {
            $message = "Dépense enregistrée avec succès";
        } else {
            $message = "Erreur: " . mysqli_error($conn);
        }
        
        // Générer un nouveau token après soumission réussie
        $_SESSION['form_token'] = bin2hex(random_bytes(32));
    }
}

// Liste des magasins
$magasins = ["Carrefour", "Auchan", "Leclerc", "Intermarché", "Casino"];
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des Dépenses</title>
    <style>
        :root {
            --primary-blue: #2c3e50;
            --secondary-blue: #3498db;
            --light-gray: #ecf0f1;
            --dark-gray: #7f8c8d;
        }
        
        body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 20px;
            background-color: var(--light-gray);
        }
        
        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
            background-color: white;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        
        h1 {
            color: var(--primary-blue);
            text-align: center;
            margin-bottom: 30px;
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        label {
            display: block;
            margin-bottom: 5px;
            color: var(--primary-blue);
            font-weight: bold;
        }
        
        input, select {
            width: 100%;
            padding: 8px;
            border: 1px solid var(--dark-gray);
            border-radius: 4px;
            font-size: 16px;
        }
        
        button {
            background-color: var(--secondary-blue);
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            width: 100%;
        }
        
        button:hover {
            background-color: var(--primary-blue);
        }
        
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 30px;
        }
        
        th, td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid var(--dark-gray);
        }
        
        th {
            background-color: var(--secondary-blue);
            color: white;
        }
        
        tr:nth-child(even) {
            background-color: var(--light-gray);
        }
        
        .message {
            padding: 10px;
            margin: 20px 0;
            border-radius: 4px;
            text-align: center;
            background-color: #d4edda;
            color: #155724;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Gestion des Dépenses</h1>
        
        <?php if(isset($message)): ?>
            <div class="message"><?php echo $message; ?></div>
        <?php endif; ?>
        
        <form method="POST" action="">
            <!-- Ajout du champ token caché -->
            <input type="hidden" name="token" value="<?php echo $_SESSION['form_token']; ?>">
            
            <div class="form-group">
                <label for="datedep">Date de la dépense</label>
                <input type="date" id="datedep" name="datedep" required>
            </div>
            
            <div class="form-group">
                <label for="libelle">Libellé</label>
                <input type="text" id="libelle" name="libelle" required>
            </div>
            
            <div class="form-group">
                <label for="montant">Montant</label>
                <input type="number" id="montant" name="montant" step="0.01" required>
            </div>
            
            <div class="form-group">
                <label for="magasin">Magasin</label>
                <select id="magasin" name="magasin" required>
                    <option value="">Sélectionnez un magasin</option>
                    <?php foreach($magasins as $mag): ?>
                        <option value="<?php echo $mag; ?>"><?php echo $mag; ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            
            <button type="submit">Enregistrer la dépense</button>
        </form>
        
        <table>
            <thead>
                <tr>
                    <th>Date</th>
                    <th>Libellé</th>
                    <th>Montant</th>
                    <th>Magasin</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $sql = "SELECT * FROM magasindep ORDER BY datedep DESC";
                $result = mysqli_query($conn, $sql);
                
                while($row = mysqli_fetch_assoc($result)):
                ?>
                <tr>
                    <td><?php echo date('d/m/Y', strtotime($row['datedep'])); ?></td>
                    <td><?php echo htmlspecialchars($row['libelle']); ?></td>
                    <td><?php echo number_format($row['montant'], 2, ',', ' '); ?> FCFA</td>
                    <td><?php echo htmlspecialchars($row['magasin']); ?></td>
                </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>
</body>
</html>