<?php
session_start();
include 'db_connect.php';
mysqli_set_charset($conn, 'utf8');

// Fonction pour sécuriser les entrées
function secure($data) {
    global $conn;
    return mysqli_real_escape_string($conn, htmlspecialchars($data));
}

// Traitement de la recherche par date (AJAX)
if(isset($_GET['action']) && $_GET['action'] == 'search') {
    $startDate = isset($_GET['startDate']) ? secure($_GET['startDate']) : null;
    $endDate = isset($_GET['endDate']) ? secure($_GET['endDate']) : null;
    
    $sql = "SELECT * FROM montant_depenses WHERE 1=1";
    
    if ($startDate) {
        $sql .= " AND date_creation >= '$startDate'";
    }
    if ($endDate) {
        $sql .= " AND date_creation <= '$endDate'";
    }
    
    $sql .= " ORDER BY date_creation DESC";
    $result = $conn->query($sql);
    $expenses = [];
    
    if ($result->num_rows > 0) {
        while($row = $result->fetch_assoc()) {
            $expenses[] = [
                'motif' => htmlspecialchars($row['motif']),
                'raison' => htmlspecialchars($row['raison']),
                'nom_interesse' => htmlspecialchars($row['nom_interesse']),
                'date_creation' => date('d/m/Y', strtotime($row['date_creation']))
            ];
        }
    }
    
    header('Content-Type: application/json');
    echo json_encode($expenses);
    exit;
}

// Traitement du formulaire d'ajout
if ($_SERVER["REQUEST_METHOD"] == "POST" && !isset($_GET['action'])) {
    $motif = secure($_POST['motif']);
    $raison = secure($_POST['raison']);
    $nom_interesse = secure($_POST['nom_interesse']);
    $date_creation = date('Y-m-d');

    $sql = "INSERT INTO montant_depenses (motif, raison, nom_interesse, date_creation) 
            VALUES ('$motif', '$raison', '$nom_interesse', '$date_creation')";

    if ($conn->query($sql) === TRUE) {
        $response = ['success' => true, 'message' => 'Dépense enregistrée avec succès'];
    } else {
        $response = ['success' => false, 'message' => 'Erreur: ' . $conn->error];
    }

    if(isset($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest') {
        header('Content-Type: application/json');
        echo json_encode($response);
        exit;
    }
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Gestion des Ventes</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" />
    <style>
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #34495e;
            --accent-color: #517398;
            --success-color: #2ecc71;
            --error-color: #e74c3c;
        }

        body {
            font-family: 'Segoe UI', Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f5f6fa;
        }
        
        .top-nav {
            background-color: var(--primary-color);
            padding: 15px;
            color: white;
        }
        
        .top-nav a {
            color: white;
            text-decoration: none;
            margin-right: 20px;
            font-size: 14px;
            padding: 5px 10px;
            border-radius: 4px;
            transition: background-color 0.3s;
        }
        
        .top-nav a:hover {
            background-color: rgba(255, 255, 255, 0.1);
        }
        
        .sidebar {
            width: 200px;
            background-color: var(--secondary-color);
            color: white;
            height: 100vh;
            position: fixed;
            padding-top: 20px;
        }

        .main-content {
            margin-left: 210px;
            padding: 30px;
            animation: fadeIn 0.5s ease;
        }

        .form-container {
            background: white;
            padding: 25px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin-bottom: 30px;
            animation: slideIn 0.5s ease;
        }

        .form-group {
            margin-bottom: 20px;
            position: relative;
        }

        .form-group label {
            display: block;
            margin-bottom: 8px;
            color: var(--primary-color);
            font-weight: 500;
            transition: all 0.3s ease;
        }

        .form-control {
            width: 100%;
            padding: 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            transition: all 0.3s ease;
            box-sizing: border-box;
        }

        .form-control:focus {
            border-color: var(--accent-color);
            box-shadow: 0 0 0 2px rgba(81,115,152,0.2);
            outline: none;
        }

        .btn {
            background-color: var(--accent-color);
            color: white;
            padding: 12px 24px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: all 0.3s ease;
            font-weight: 500;
        }

        .btn:hover {
            background-color: #3d5876;
            transform: translateY(-1px);
        }

        .search-section {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            margin-bottom: 30px;
            animation: slideIn 0.5s ease;
        }

        .date-picker {
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-right: 10px;
            width: 200px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            border-radius: 8px;
            overflow: hidden;
            animation: slideIn 0.5s ease;
        }

        th {
            background-color: var(--accent-color);
            color: white;
            padding: 15px;
            text-align: left;
        }

        td {
            padding: 12px 15px;
            border-bottom: 1px solid #eee;
        }

        tr:hover {
            background-color: #f8f9fa;
        }

        .message {
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
            animation: fadeIn 0.5s ease;
        }

        .success-message {
            background-color: #d4edda;
            color: #155724;
        }

        .error-message {
            background-color: #f8d7da;
            color: #721c24;
        }

        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }

        @keyframes slideIn {
            from { 
                opacity: 0;
                transform: translateY(20px);
            }
            to { 
                opacity: 1;
                transform: translateY(0);
            }
        }

        /* Loading animation */
        .loading {
            text-align: center;
            padding: 20px;
            display: none;
        }

        .loading:after {
            content: "...";
            animation: dots 1.5s steps(5, end) infinite;
        }

        @keyframes dots {
            0%, 20% { content: "."; }
            40% { content: ".."; }
            60% { content: "..."; }
            80%, 100% { content: ""; }
        }
    </style>
</head>
<body>
    <div class="top-nav">
        <a href="page_caisse.php">Accueil</a>
        <a href="dashboard.php">Ventes</a>
        <a href="enregistre_depense.php">Dépenses</a>
        <a href="voir_point_caisse.php">Voir point</a>
        <a href="index.php">Déconnexion</a>
    </div>
    
    <div class="sidebar">
        <div class="logo-container">
            <img src="image/logognimaholding.PNG" alt="Logo" style="max-width: 100%; max-height: 150%;">
        </div>
        <div style="padding: 15px;">
            <input type="text" placeholder="Rechercher" style="width: 90%;" id="sidebarSearch">
        </div>
    </div>
    
    <div class="main-content">
        <div class="form-container">
            <h2>Gestion des dépenses</h2>
            <div id="messageContainer"></div>
            <form id="expenseForm" method="post">
                <div class="form-group">
                    <label>Motif:</label>
                    <input type="text" name="motif" class="form-control" required>
                </div>
                <div class="form-group">
                    <label>Raison:</label>
                    <textarea name="raison" class="form-control" rows="4" required></textarea>
                </div>
                <div class="form-group">
                    <label>Nom de l'intéressé:</label>
                    <input type="text" name="nom_interesse" class="form-control" required>
                </div>
                <button type="submit" class="btn">Enregistrer</button>
            </form>
        </div>

        <div class="search-section">
            <h3>Rechercher par date</h3>
            <div style="display: flex; gap: 10px; margin-bottom: 15px;">
                <input type="date" id="startDate" class="date-picker" placeholder="Date début">
                <input type="date" id="endDate" class="date-picker" placeholder="Date fin">
            </div>
        </div>

        <div class="loading">Chargement des données</div>

        <div id="resultsTable">
            <table>
                <thead>
                    <tr>
                        <th>Motif</th>
                        <th>Raison</th>
                        <th>Nom de l'intéressé</th>
                        <th>Date</th>
                    </tr>
                </thead>
                <tbody id="expenseTableBody">
                </tbody>
            </table>
        </div>
    </div>

    <script>
    $(document).ready(function() {
        // Form submission with animation
        $('#expenseForm').on('submit', function(e) {
            e.preventDefault();
            
            $.ajax({
                type: 'POST',
                url: window.location.href,
                data: $(this).serialize(),
                success: function(response) {
                    const messageClass = response.success ? 'success-message' : 'error-message';
                    const message = $('<div class="message ' + messageClass + '">' + response.message + '</div>')
                        .hide()
                        .prependTo('#messageContainer')
                        .fadeIn();
                    
                    if(response.success) {
                        $('#expenseForm')[0].reset();
                        loadExpenses();
                    }
                    
                    setTimeout(() => message.fadeOut(() => message.remove()), 3000);
                }
            });
        });

        // Date search functionality
        function loadExpenses() {
            const startDate = $('#startDate').val();
            const endDate = $('#endDate').val();
            $('.loading').fadeIn();

            $.ajax({
                type: 'GET',
                url: window.location.href,
                data: { 
                    action: 'search',
                    startDate: startDate, 
                    endDate: endDate 
                },
                success: function(expenses) {
                    const tbody = $('#expenseTableBody');
                    tbody.empty();

                    if(expenses.length === 0) {
                        tbody.append('<tr><td colspan="4" style="text-align: center;">Aucune dépense trouvée</td></tr>');
                    } else {
                        expenses.forEach(expense => {
                            tbody.append(`
                                <tr>
                                    <td>${expense.motif}</td>
                                    <td>${expense.raison}</td>
                                    <td>${expense.nom_interesse}</td>
                                    <td>${expense.date_creation}</td>
                                </tr>
                            `);
                        });
                    }
                },
                complete: function() {
                    $('.loading').fadeOut();
                }
            });
        }

        // Load expenses when dates change
        $('#startDate, #endDate').on('change', loadExpenses);

        // Initial load
        loadExpenses();
    });
    </script>
</body>
</html>