<?php
session_start();
include 'db_connect.php';

// Traitement de la suppression
if(isset($_POST['delete'])) {
    $id = $_POST['id'];
    $sql = "DELETE FROM ravitaillements WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $id);
    $stmt->execute();
}

// Traitement de l'ajout/modification
if(isset($_POST['submit'])) {
    $lieu = $_POST['lieu'];
    $date_heure = $_POST['date_heure'];
    $produit = $_POST['produit'];
    $quantite = $_POST['quantite'];
    $prix = $_POST['prix'];
    $total = $quantite * $prix;

    if(isset($_POST['id']) && $_POST['id'] != '') {
        // Modification
        $id = $_POST['id'];
        $sql = "UPDATE ravitaillements SET lieu=?, date_heure=?, produit=?, quantite=?, prix=?, total=? WHERE id=?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sssiidi", $lieu, $date_heure, $produit, $quantite, $prix, $total, $id);
    } else {
        // Ajout
        $sql = "INSERT INTO ravitaillements (lieu, date_heure, produit, quantite, prix, total) VALUES (?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sssiid", $lieu, $date_heure, $produit, $quantite, $prix, $total);
    }
    $stmt->execute();
}

// Récupération des données pour modification
$edit_data = null;
if(isset($_GET['edit'])) {
    $id = $_GET['edit'];
    $sql = "SELECT * FROM ravitaillements WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    $edit_data = $result->fetch_assoc();
}
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des Ravitaillements</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/3.7.0/chart.min.js"></script>
    <style>
        /* Base styles */
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            background-color: #f4f4f4;
        }

        /* Sidebar styles */
        .sidebar {
            width: 250px;
            background-color: #001f3f;
            color: #fff;
            height: 100vh;
            position: fixed;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        .sidebar .logo-container {
            width: 100%;
            padding: 20px 0;
            text-align: center;
        }

        .sidebar ul {
            list-style: none;
            padding: 0;
            margin: 0;
            width: 100%;
        }

        .sidebar ul li {
            padding: 15px 20px;
            border-bottom: 1px solid rgba(255, 255, 255, 0.2);
        }

        .sidebar ul li a {
            color: white;
            text-decoration: none;
            display: block;
            width: 100%;
        }

        .sidebar ul li:hover {
            background-color: #002b4e;
        }

        /* Main content styles */
        .main-content {
            margin-left: 250px;
            padding: 20px;
            min-height: 100vh;
        }

        /* Form styles */
        .form-container {
            background: white;
            padding: 20px;
            border-radius: 8px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-group input {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
            box-sizing: border-box;
        }

        .submit-btn {
            background-color: #001f3f;
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .submit-btn:hover {
            background-color: #003366;
        }

        /* Table styles */
        .table-container {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
            overflow-x: auto;
        }

        table {
            width: 100%;
            border-collapse: collapse;
        }

        th {
            background-color: #001f3f;
            color: white;
            padding: 12px;
            text-align: left;
        }

        td {
            padding: 12px;
            border-bottom: 1px solid #ddd;
        }

        .action-buttons {
            display: flex;
            gap: 10px;
        }

        .edit-btn, .delete-btn {
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .edit-btn {
            background-color: #4CAF50;
            color: white;
        }

        .delete-btn {
            background-color: #f44336;
            color: white;
        }
    </style>
</head>
<body>
    <div class="sidebar">
        <div class="logo-container">
            <img src="image/logognimaholding.PNG" alt="Logo" style="max-width: 100%;">
        </div>
        <ul>
            <li><a href="brod_gestionnaire.php">Accueil</a></li>
            <li><a href="page_produit_bon.php">Produits</a></li>
            <li><a href="enregistrer_fournisseur.php">Fournisseurs</a></li>
            <li><a href="enregistrer_commande.php">Commandes</a></li>
            <li><a href="enregistrer_ravitaillements.php">Ravitaillement</a></li>
            <li><a href="#">Tous détail produit</a></li>
            <li><a href="#">Statistiques</a></li>
            <li><a href="index.php">Déconnexion</a></li>
        </ul>
    </div>

    <div class="main-content">
        <div class="form-container">
            <h2><?php echo isset($_GET['edit']) ? 'Modifier' : 'Ajouter' ?> un ravitaillement</h2>
            <form method="POST">
                <input type="hidden" name="id" value="<?php echo $edit_data ? $edit_data['id'] : ''; ?>">
                
                <div class="form-group">
                    <label>Lieu:</label>
                    <input type="text" name="lieu" required value="<?php echo $edit_data ? $edit_data['lieu'] : ''; ?>">
                </div>
                
                <div class="form-group">
                    <label>Date et Heure:</label>
                    <input type="datetime-local" name="date_heure" required 
                           value="<?php echo $edit_data ? date('Y-m-d\TH:i', strtotime($edit_data['date_heure'])) : ''; ?>">
                </div>
                
                <div class="form-group">
                    <label>Produit:</label>
                    <input type="text" name="produit" required value="<?php echo $edit_data ? $edit_data['produit'] : ''; ?>">
                </div>
                
                <div class="form-group">
                    <label>Quantité:</label>
                    <input type="number" name="quantite" required value="<?php echo $edit_data ? $edit_data['quantite'] : ''; ?>">
                </div>
                
                <div class="form-group">
                    <label>Prix:</label>
                    <input type="number" step="0.01" name="prix" required value="<?php echo $edit_data ? $edit_data['prix'] : ''; ?>">
                </div>
                
                <button type="submit" name="submit" class="submit-btn">
                    <?php echo isset($_GET['edit']) ? 'Modifier' : 'Ajouter' ?>
                </button>
            </form>
        </div>

        <div class="table-container">
            <h2>Liste des ravitaillements</h2>
            <table>
                <thead>
                    <tr>
                        <th>Lieu</th>
                        <th>Date et Heure</th>
                        <th>Produit</th>
                        <th>Quantité</th>
                        <th>Prix</th>
                        <th>Total</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $sql = "SELECT * FROM ravitaillements ORDER BY date_heure DESC";
                    $result = $conn->query($sql);
                    while($row = $result->fetch_assoc()):
                    ?>
                    <tr>
                        <td><?php echo htmlspecialchars($row['lieu']); ?></td>
                        <td><?php echo date('d/m/Y H:i', strtotime($row['date_heure'])); ?></td>
                        <td><?php echo htmlspecialchars($row['produit']); ?></td>
                        <td><?php echo htmlspecialchars($row['quantite']); ?></td>
                        <td><?php echo number_format($row['prix']); ?> fcfa</td>
                        <td><?php echo number_format($row['total']); ?> fcfa</td>
                        <td>
                            <div class="action-buttons">
                                <a href="?edit=<?php echo $row['id']; ?>" class="edit-btn">✏️</a>
                                <form method="POST" style="display: inline;">
                                    <input type="hidden" name="id" value="<?php echo $row['id']; ?>">
                                    <button type="submit" name="delete" class="delete-btn" 
                                            onclick="return confirm('Êtes-vous sûr de vouloir supprimer ?')">
                                        🗑️
                                    </button>
                                </form>
                            </div>
                        </td>
                    </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>
</html>