<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Connexion des Employés</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        :root {
            --primary-color: #2980b9;
            --secondary-color: #3498db;
            --text-color: #2c3e50;
            --shadow-color: rgba(0, 0, 0, 0.2);
            --card-background: rgba(255, 255, 255, 0.95);
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            background: linear-gradient(135deg, #667eea, #764ba2);
            min-height: 100vh;
            display: flex;
            justify-content: center;
            align-items: center;
        }

        .container {
            width: 900px;
            height: 500px;
            display: flex;
            background: var(--card-background);
            border-radius: 20px;
            box-shadow: 0 15px 35px var(--shadow-color);
            overflow: hidden;
        }

        .left-panel {
            flex: 0.4;
            background: linear-gradient(145deg, var(--primary-color), var(--secondary-color));
            padding: 20px;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
        }

        .carousel {
            height: 70%;
            position: relative;
            overflow: hidden;
            border-radius: 15px;
        }

        .carousel-inner {
            height: 100%;
            display: flex;
            transition: transform 0.5s ease-in-out;
        }

        .carousel-item {
            min-width: 100%;
            height: 100%;
        }

        .carousel-item img {
            width: 100%;
            height: 100%;
            object-fit: cover;
            border-radius: 12px;
        }

        .button-group {
            display: flex;
            flex-direction: column;
            gap: 10px;
            margin-top: 20px;
        }

        .role-button {
            padding: 12px;
            border: none;
            border-radius: 8px;
            background: rgba(255, 255, 255, 0.1);
            color: white;
            font-weight: bold;
            cursor: pointer;
            transition: all 0.3s;
            backdrop-filter: blur(5px);
        }

        .role-button:hover {
            background: rgba(255, 255, 255, 0.2);
            transform: translateX(5px);
        }

        .role-button.active {
            background: rgba(255, 255, 255, 0.3);
            transform: scale(1.02);
        }

        .right-panel {
            flex: 0.6;
            padding: 40px;
            display: flex;
            flex-direction: column;
            justify-content: center;
        }

        .form-title {
            color: var(--text-color);
            font-size: 24px;
            margin-bottom: 25px;
            text-align: center;
        }

        .form-group {
            margin-bottom: 20px;
        }

        .form-group label {
            display: block;
            margin-bottom: 8px;
            color: var(--text-color);
            font-size: 14px;
        }

        .input-icon {
            position: relative;
        }

        .input-icon input {
            width: 100%;
            padding: 12px 15px;
            border: 2px solid #e1e1e1;
            border-radius: 8px;
            font-size: 14px;
            transition: all 0.3s;
            background: white;
        }

        .input-icon input:focus {
            border-color: var(--primary-color);
            box-shadow: 0 0 0 3px rgba(41, 128, 185, 0.1);
            outline: none;
        }

        .input-icon i {
            position: absolute;
            right: 15px;
            top: 50%;
            transform: translateY(-50%);
            color: #999;
        }

        .submit-btn {
            width: 100%;
            padding: 12px;
            border: none;
            border-radius: 8px;
            background: linear-gradient(145deg, var(--primary-color), var(--secondary-color));
            color: white;
            font-size: 16px;
            font-weight: bold;
            cursor: pointer;
            transition: all 0.3s;
        }

        .submit-btn:hover {
            transform: translateY(-2px);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.2);
        }

        .error-message {
            background-color: #ff6b6b;
            color: white;
            padding: 10px;
            border-radius: 8px;
            margin-top: 20px;
            text-align: center;
            font-size: 14px;
            animation: shake 0.5s;
        }

        .hidden {
            display: none;
        }

        @keyframes shake {
            0%, 100% { transform: translateX(0); }
            25% { transform: translateX(-5px); }
            75% { transform: translateX(5px); }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="left-panel">
            <div class="carousel">
                <div class="carousel-inner">
                    <div class="carousel-item">
                        <img src="image/ujgdvgfbbns.jpg" alt="Image 1">
                    </div>
                    <div class="carousel-item">
                        <img src="image/gqdhshdgfgyhdsq.jpg" alt="Image 2">
                    </div>
                    <div class="carousel-item">
                        <img src="image/bgghdgswh.jgp" alt="Image 3">
                    </div>
                </div>
            </div>
            <div class="button-group">
                <button class="role-button active" onclick="showForm('admin-form')">
                    <i class="fas fa-user-shield"></i> Administrateur
                </button>
                <button class="role-button" onclick="showForm('gestionnaire-form')">
                    <i class="fas fa-user-tie"></i> Gestionnaire
                </button>
                <button class="role-button" onclick="showForm('caissiere-form')">
                    <i class="fas fa-cash-register"></i> Caissière
                </button>
            </div>
        </div>

        <div class="right-panel">
            <form method="POST" action="" id="admin-form" class="hidden">
                <h2 class="form-title">Connexion Administrateur</h2>
                <div class="form-group">
                    <label>Email :</label>
                    <div class="input-icon">
                        <input type="email" name="email" required>
                        <i class="fas fa-envelope"></i>
                    </div>
                </div>
                <div class="form-group">
                    <label>Mot de passe :</label>
                    <div class="input-icon">
                        <input type="password" name="password" required>
                        <i class="fas fa-lock"></i>
                    </div>
                </div>
                <input type="hidden" name="poste" value="administrateur">
                <button type="submit" name="connexion" class="submit-btn">
                    <i class="fas fa-sign-in-alt"></i> Se Connecter
                </button>
            </form>

            <form method="POST" action="" id="gestionnaire-form" class="hidden">
                <h2 class="form-title">Connexion Gestionnaire</h2>
                <div class="form-group">
                    <label>Email :</label>
                    <div class="input-icon">
                        <input type="email" name="email" required>
                        <i class="fas fa-envelope"></i>
                    </div>
                </div>
                <div class="form-group">
                    <label>Mot de passe :</label>
                    <div class="input-icon">
                        <input type="password" name="password" required>
                        <i class="fas fa-lock"></i>
                    </div>
                </div>
                <input type="hidden" name="poste" value="gestionnaire">
                <button type="submit" name="connexion" class="submit-btn">
                    <i class="fas fa-sign-in-alt"></i> Se Connecter
                </button>
            </form>

            <form method="POST" action="" id="caissiere-form" class="hidden">
                <h2 class="form-title">Connexion Caissière</h2>
                <div class="form-group">
                    <label>Nom d'utilisateur :</label>
                    <div class="input-icon">
                        <input type="text" name="username" required>
                        <i class="fas fa-user"></i>
                    </div>
                </div>
                <div class="form-group">
                    <label>Mot de passe :</label>
                    <div class="input-icon">
                        <input type="password" name="password" required>
                        <i class="fas fa-lock"></i>
                    </div>
                </div>
                <input type="hidden" name="poste" value="caissiere">
                <button type="submit" name="connexion" class="submit-btn">
                    <i class="fas fa-sign-in-alt"></i> Se Connecter
                </button>
            </form>
        </div>
    </div>

    <script>
        const carousel = document.querySelector('.carousel-inner');
        let currentSlide = 0;
        const slides = document.querySelectorAll('.carousel-item');
        
        function nextSlide() {
            currentSlide = (currentSlide + 1) % slides.length;
            carousel.style.transform = `translateX(-${currentSlide * 100}%)`;
        }

        setInterval(nextSlide, 3000);

        function showForm(formId) {
            document.querySelectorAll('form').forEach(form => {
                form.classList.add('hidden');
            });
            
            document.getElementById(formId).classList.remove('hidden');
            
            document.querySelectorAll('.role-button').forEach(button => {
                button.classList.remove('active');
            });
            event.target.classList.add('active');
        }

        showForm('admin-form');
    </script>
</body>
</html>