<?php
// Connexion à la base de données
session_start();
include 'db_connect.php';

// Initialisation des variables
$totalProduits = 0;
$totalVentes = 0;
$totalBenefice = 0;
$donnees = [];

// Requête pour récupérer les totaux par produit
$sql = "SELECT 
            p.id AS produit_id,
            p.name AS produit_nom,
            SUM(c.quantite) AS total_ventes,
            SUM(c.quantite * c.prix) AS total_achats,
            (SUM(c.quantite * c.prix) - SUM(p.stock * p.price)) AS benefice
        FROM products p
        LEFT JOIN commandes c ON p.id = c.id
        GROUP BY p.id, p.name";

if ($result = $conn->query($sql)) {
    // Parcourir les résultats
    if ($result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            $donnees[] = $row;
            $totalProduits += $row['total_achats'] ?? 0;
            $totalVentes += $row['total_ventes'] ?? 0;
            $totalBenefice += $row['benefice'] ?? 0;
        }
    }
    $result->free();
} else {
    // Affichage de l'erreur SQL pour débogage
    die("Erreur dans la requête SQL : " . $conn->error);
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tableau des Ventes et Bénéfices</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <style>
        .info-box {
            display: flex;
            justify-content: space-around;
            margin-bottom: 20px;
        }
        .info-box div {
            padding: 20px;
            border-radius: 8px;
            color: #fff;
            font-size: 18px;
            font-weight: bold;
            text-align: center;
        }
        .total-produits { background-color: #6c757d; }
        .total-ventes { background-color: #28a745; }
        .total-benefices { background-color: #ffc107; color: #000; }
    </style>
</head>
<body>
<div class="container mt-5">
    <div class="info-box">
        <div class="total-produits">Total Achats : <?= number_format($totalProduits) ?> FCFA</div>
        <div class="total-ventes">Total Ventes : <?= number_format($totalVentes) ?> FCFA</div>
        <div class="total-benefices">Total Bénéfices : <?= number_format($totalBenefice) ?> FCFA</div>
    </div>

    <div class="mb-3">
        <input type="text" id="search" class="form-control" placeholder="Rechercher un produit...">
    </div>

    <table class="table table-bordered table-striped">
        <thead>
        <tr>
            <th>Nom du Produit</th>
            <th>Total Ventes</th>
            <th>Total Achats</th>
            <th>Bénéfice</th>
        </tr>
        </thead>
        <tbody id="productTable">
        <?php foreach ($donnees as $produit) : ?>
            <tr>
                <td><?= htmlspecialchars($produit['produit_nom']) ?></td>
                <td><?= number_format($produit['total_ventes'], 2) ?> €</td>
                <td><?= number_format($produit['total_achats'], 2) ?> €</td>
                <td><?= number_format($produit['benefice'], 2) ?> €</td>
            </tr>
        <?php endforeach; ?>
        </tbody>
    </table>
</div>

<script>
    $(document).ready(function () {
        $('#search').on('keyup', function () {
            var value = $(this).val().toLowerCase();
            $('#productTable tr').filter(function () {
                $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1);
            });
        });
    });
</script>
</body>
</html>
