<?php
session_start();

include 'db_connect.php';

// Traitement du formulaire
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (!isset($_SESSION['form_submitted'])) {
        $name = $_POST['name'];
        $type_pro = $_POST['type_pro'];
        $barcode = $_POST['barcode'];
        $stock = $_POST['stock'];
        $price = $_POST['price'];
        $category = $_POST['category'];
        $fournisseur_id = $_POST['fournisseur_id'];
        
        // Calcul automatique du seuil d'alerte (30% du stock)
        $seuil_alerte = $stock * 0.3;
        
       $sql = "INSERT INTO products (name, type_pro, barcode, stock, price, category, seuil_alerte, fournisseur_id, created_at) 
        VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW())";

$stmt = $conn->prepare($sql);
// Correction de la chaîne de type en 'sssiisdi' (8 paramètres au lieu de 9)
$stmt->bind_param("sssiisdi", $name, $type_pro, $barcode, $stock, $price, $category, $seuil_alerte, $fournisseur_id);
        if ($stmt->execute()) {
            $_SESSION['form_submitted'] = true;
            echo "<div class='alert alert-success'>Produit enregistré avec succès!</div>";
        } else {
            echo "<div class='alert alert-danger'>Erreur lors de l'enregistrement!</div>";
        }
        $stmt->close();
    }
} else {
    unset($_SESSION['form_submitted']);
}

// Récupération des statistiques
$sql_stats = "SELECT COUNT(*) as total_products, SUM(price) as total_price FROM products";
$result_stats = $conn->query($sql_stats);
$stats = $result_stats->fetch_assoc();

// Récupération des statistiques
$sql_stats = "SELECT COUNT(*) as total_products, SUM(price) as total_price FROM products";
$result_stats = $conn->query($sql_stats);
if ($result_stats) {
    $stats = $result_stats->fetch_assoc();
} else {
    echo "<div class='alert alert-danger'>Erreur lors de la récupération des statistiques : " . $conn->error . "</div>";
    $stats = ['total_products' => 0, 'total_price' => 0];
}

// Récupération des fournisseurs
$sql_fournisseurs = "SELECT * FROM fournisseurs ORDER BY nom";
$result_fournisseurs = $conn->query($sql_fournisseurs);
if (!$result_fournisseurs) {
    echo "<div class='alert alert-danger'>Erreur lors de la récupération des fournisseurs : " . $conn->error . "</div>";
}

// Récupération des produits
$sql_products = "SELECT p.*, f.nom as fournisseur_name 
                FROM products p 
                LEFT JOIN fournisseurs f ON p.id = f.id 
                ORDER BY p.created_at DESC";
$result_products = $conn->query($sql_products);
if (!$result_products) {
    echo "<div class='alert alert-danger'>Erreur lors de la récupération des produits : " . $conn->error . "</div>";
}

?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>Gestion des Produits</title>
    <style>
        /* Garder le même CSS que dans le code original */
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #3498db;
            --background-color: #f5f6fa;
        }

        body {
            font-family: 'Arial', sans-serif;
            background-color: var(--background-color);
            margin: 0;
            padding: 20px;
        }

        .stats-container {
            display: flex;
            justify-content: space-between;
            margin-bottom: 30px;
        }

        .stat-box {
            background: linear-gradient(135deg, var(--secondary-color), var(--primary-color));
            color: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 10px 20px rgba(0,0,0,0.2);
            flex: 1;
            margin: 0 10px;
            transform: perspective(1000px) rotateX(5deg);
            transition: transform 0.3s ease;
        }

        .stat-box:hover {
            transform: perspective(1000px) rotateX(0deg);
        }

        .form-container {
            background: white;
            padding: 30px;
            border-radius: 15px;
            box-shadow: 0 15px 30px rgba(0,0,0,0.1);
            margin-bottom: 30px;
        }

        .form-group {
            margin-bottom: 20px;
        }

        input, select {
            width: 100%;
            padding: 10px;
            border: 2px solid #ddd;
            border-radius: 5px;
            transition: border-color 0.3s ease;
        }

        input:focus, select:focus {
            border-color: var(--secondary-color);
            outline: none;
        }

        button {
            background: var(--secondary-color);
            color: white;
            padding: 12px 25px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: transform 0.3s ease;
        }

        button:hover {
            transform: translateY(-2px);
        }

        .products-table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0 10px;
        }

        .products-table th {
            background: var(--primary-color);
            color: white;
            padding: 15px;
            text-align: left;
        }

        .products-table tr {
            background: white;
            box-shadow: 0 5px 15px rgba(0,0,0,0.1);
            transform: perspective(1000px);
            transition: transform 0.3s ease;
        }

        .products-table tr:hover {
            transform: perspective(1000px) translateZ(20px);
        }

        .products-table td {
            padding: 15px;
            border-top: 1px solid #ddd;
            border-bottom: 1px solid #ddd;
        }

        .products-table td:first-child {
            border-left: 1px solid #ddd;
            border-top-left-radius: 5px;
            border-bottom-left-radius: 5px;
        }

        .products-table td:last-child {
            border-right: 1px solid #ddd;
            border-top-right-radius: 5px;
            border-bottom-right-radius: 5px;
        }
    </style>
</head>
<body>
    <!-- Statistiques -->
    <div class="stats-container">
        <div class="stat-box">
            <h3>Total Produits</h3>
            <p><?php echo $stats['total_products']; ?></p>
        </div>
        <div class="stat-box">
            <h3>Prix Total</h3>
            <p><?php echo number_format($stats['total_price']); ?> Fcfa</p>
        </div>
    </div>

    <!-- Formulaire d'enregistrement -->
    <div class="form-container">
        <h2>Ajouter un nouveau produit</h2>
        <form method="POST">
            <div class="form-group">
                <input type="text" name="name" placeholder="Nom du produit" required>
            </div>

 <div class="form-group">
                <select name="type_pro" required>
                    <option value="">Sélectionner le type de produit</option>
                    <option value="gros">Gros</option>
                    <option value="detail">Détail</option>
                </select>
            </div>

            <div class="form-group">
                <input type="text" name="barcode" placeholder="Code-barres" required>
            </div>
            <div class="form-group">
                <input type="number" name="stock" placeholder="Stock" required>
            </div>
            <div class="form-group">
                <input type="number" name="price" step="0.01" placeholder="Prix" required>
            </div>
            <div class="form-group">
                <input type="text" name="category" placeholder="Catégorie" required>
            </div>
           
            <div class="form-group">
                <select name="fournisseur_id" required>
                    <option value="">Sélectionner un fournisseur</option>
                    <?php while($fournisseur = $result_fournisseurs->fetch_assoc()): ?>
                        <option value="<?php echo $fournisseur['id']; ?>">
                            <?php echo htmlspecialchars($fournisseur['nom']); ?>
                        </option>
                    <?php endwhile; ?>
                </select>
            </div>
            <button type="submit">Enregistrer le produit</button>
        </form>
    </div>

    <!-- Tableau des produits -->
    <table class="products-table">
        <thead>
            <tr>
                <th>Nom</th>
                <th>Type</th>
                <th>Code-barres</th>
                <th>Stock</th>
                <th>Prix</th>
                <th>Catégorie</th>
                
                <th>Seuil Alerte</th>
                <th>Fournisseur</th>
                <th>Date création</th>
            </tr>
        </thead>
        <tbody>
            <?php while($row = $result_products->fetch_assoc()): ?>
            <tr>
                <td><?php echo htmlspecialchars($row['name']); ?></td>
                <td><?php echo htmlspecialchars($row['type_pro']); ?></td>
                <td><?php echo htmlspecialchars($row['barcode']); ?></td>
                <td><?php echo htmlspecialchars($row['stock']); ?></td>
                <td><?php echo htmlspecialchars($row['price']); ?> Fcfa</td>
                <td><?php echo htmlspecialchars($row['category']); ?></td>
                
                <td><?php echo htmlspecialchars($row['seuil_alerte']); ?></td>
                <td><?php echo htmlspecialchars($row['fournisseur_name']); ?></td>
                <td><?php echo htmlspecialchars($row['created_at']); ?></td>
            </tr>
            <?php endwhile; ?>
        </tbody>
    </table>

    <?php $conn->close(); ?>
</body>
</html>