<?php
session_start();
include 'db_connect.php';

// Vérification si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

// Récupération des ventes du jour pour l'utilisateur connecté
$user_id = $_SESSION['user_id'];
$today = date('Y-m-d');

// Correction de la requête sales
$query_sales = "SELECT s.*, p.name, p.type_pro, p.price 
                FROM ventes s 
                JOIN products p ON s.id = p.id 
                WHERE s.utilisateur_id  = ? AND DATE(s.date_heure) = ?
                ORDER BY s.date_heure DESC";

$stmt = mysqli_prepare($conn, $query_sales);
if ($stmt === false) {
    die('Erreur de préparation de la requête : ' . mysqli_error($conn));
}

mysqli_stmt_bind_param($stmt, "is", $user_id, $today);
if (!mysqli_stmt_execute($stmt)) {
    die('Erreur d\'exécution de la requête : ' . mysqli_stmt_error($stmt));
}
$result_sales = mysqli_stmt_get_result($stmt);

// Calcul des totaux
$query_totals = "SELECT 
                    SUM(s.tt_pro * p.price) as total_sales,
                    SUM(CASE WHEN p.type_pro = 'gros' THEN s.tt_pro ELSE 0 END) as total_gros,
                    SUM(CASE WHEN p.type_pro = 'detail' THEN s.tt_pro * p.price ELSE 0 END) as total_detail
                FROM ventes s 
                JOIN products p ON s.id = p.id 
                WHERE s.utilisateur_id = ? AND DATE(s.date_heure) = ?";

$stmt_totals = mysqli_prepare($conn, $query_totals);
if ($stmt_totals === false) {
    die('Erreur de préparation de la requête totaux : ' . mysqli_error($conn));
}

mysqli_stmt_bind_param($stmt_totals, "is", $user_id, $today);
if (!mysqli_stmt_execute($stmt_totals)) {
    die('Erreur d\'exécution de la requête totaux : ' . mysqli_stmt_error($stmt_totals));
}
$result_totals = mysqli_stmt_get_result($stmt_totals);
$totals = mysqli_fetch_assoc($result_totals);

// Si les totaux sont NULL, initialiser à 0
$totals['total_sales'] = $totals['total_sales'] ?? 0;
$totals['total_gros'] = $totals['total_gros'] ?? 0;
$totals['total_detail'] = $totals['total_detail'] ?? 0;
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tableau de bord des ventes</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #3498db;
            --accent-color: #e74c3c;
            --background-color: #ecf0f1;
            --card-background: #ffffff;
            --text-color: #2c3e50;
            --shadow-color: rgba(0, 0, 0, 0.1);
        }

        body {
            background: var(--background-color);
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            margin: 0;
            padding: 20px;
            min-height: 100vh;
        }

        .dashboard {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }

        .stats-container {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
            margin-bottom: 40px;
        }

        .stat-card {
            background: var(--card-background);
            border-radius: 15px;
            padding: 20px;
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            box-shadow: 
                0 10px 20px var(--shadow-color),
                0 6px 6px var(--shadow-color);
            position: relative;
            overflow: hidden;
        }

        .stat-card:hover {
            transform: translateY(-5px) scale(1.02);
            box-shadow: 
                0 15px 30px var(--shadow-color),
                0 10px 10px var(--shadow-color);
        }

        .stat-card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: linear-gradient(135deg, rgba(255,255,255,0.1) 0%, rgba(255,255,255,0) 100%);
            pointer-events: none;
        }

        .stat-card h3 {
            color: var(--primary-color);
            margin: 0 0 10px 0;
            font-size: 1.2em;
            font-weight: 600;
        }

        .value {
            color: var(--secondary-color);
            font-size: 2em;
            font-weight: bold;
            text-shadow: 2px 2px 4px var(--shadow-color);
        }

        .sales-table {
            background: var(--card-background);
            border-radius: 15px;
            padding: 25px;
            box-shadow: 
                0 10px 20px var(--shadow-color),
                0 6px 6px var(--shadow-color);
            transform: perspective(1000px) rotateX(0deg);
            transition: transform 0.3s ease;
        }

        .sales-table:hover {
            transform: perspective(1000px) rotateX(2deg);
        }

        .table-title {
            color: var(--primary-color);
            margin: 0 0 20px 0;
            font-size: 1.5em;
            font-weight: 600;
            position: relative;
            padding-bottom: 10px;
        }

        .table-title::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 0;
            width: 50px;
            height: 3px;
            background: var(--secondary-color);
            border-radius: 3px;
        }

        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0 8px;
            margin-top: -8px;
        }

        th {
            background: var(--primary-color);
            color: white;
            padding: 15px;
            text-align: left;
            font-weight: 500;
            position: sticky;
            top: 0;
            z-index: 10;
        }

        th:first-child {
            border-top-left-radius: 10px;
            border-bottom-left-radius: 10px;
        }

        th:last-child {
            border-top-right-radius: 10px;
            border-bottom-right-radius: 10px;
        }

        td {
            background: white;
            padding: 15px;
            border-top: 1px solid var(--shadow-color);
            border-bottom: 1px solid var(--shadow-color);
            transition: transform 0.2s ease, box-shadow 0.2s ease;
        }

        td:first-child {
            border-left: 1px solid var(--shadow-color);
            border-top-left-radius: 10px;
            border-bottom-left-radius: 10px;
        }

        td:last-child {
            border-right: 1px solid var(--shadow-color);
            border-top-right-radius: 10px;
            border-bottom-right-radius: 10px;
        }

        tr:hover td {
            transform: scale(1.01);
            box-shadow: 0 4px 8px var(--shadow-color);
            background: rgba(255,255,255,0.95);
        }

        .empty-state {
            text-align: center;
            padding: 40px;
            color: var(--text-color);
        }

        .empty-state i {
            font-size: 4em;
            color: var(--secondary-color);
            margin-bottom: 20px;
            opacity: 0.5;
            animation: float 3s ease-in-out infinite;
        }

        @keyframes float {
            0%, 100% {
                transform: translateY(0);
            }
            50% {
                transform: translateY(-10px);
            }
        }

        @media (max-width: 768px) {
            .stats-container {
                grid-template-columns: 1fr;
            }
            
            .sales-table {
                overflow-x: auto;
            }
            
            td, th {
                padding: 10px;
            }
            
            .value {
                font-size: 1.5em;
            }
        }
        .message-container {
    display: flex;
    justify-content: space-between; /* Écarte les messages pour qu'ils soient aux extrémités */
    align-items: center; /* Aligne verticalement au centre */
    padding: 10px;
}

.message-left, .message-right {
    padding: 5px 10px;
    background-color: #f0f0f0;
    border-radius: 5px;
}

    </style>
</head>
<body>
    <div class="dashboard">
        <div class="message-container">
    <div class="message-left">
        <p onclick="window.location.href = 'dashboard.php'"> Retour</p>
    </div>
    <div class="message-right">
        <p onclick="window.location.href = 'index.php'"> Déconnexion</p>
    </div>
</div>

      
        <div class="stats-container">
            <div class="stat-card">
                <h3>Total des ventes</h3>
                <div class="value"><?php echo number_format($totals['total_sales'], 2, ',', ' '); ?> €</div>
            </div>
            <div class="stat-card">
                <h3>Produits Gros</h3>
                <div class="value"><?php echo number_format($totals['total_gros'], 0, ',', ' '); ?></div>
            </div>
            <div class="stat-card">
                <h3>Total Détail</h3>
                <div class="value"><?php echo number_format($totals['total_detail'], 2, ',', ' '); ?> €</div>
            </div>
        </div>

        <div class="sales-table">
            <h2 class="table-title">Historique des ventes du <?php echo date('d/m/Y'); ?></h2>
            
            <?php if (mysqli_num_rows($result_sales) > 0): ?>
            <table>
                <thead>
                    <tr>
                        <th>Heure</th>
                        <th>Produit</th>
                        <th>Type</th>
                        <th>Quantité</th>
                        <th>Prix unitaire</th>
                        <th>Total</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($row = mysqli_fetch_assoc($result_sales)): ?>
                    <tr>
                        <td><?php echo date('H:i', strtotime($row['date_heure'])); ?></td>
                        <td><?php echo htmlspecialchars($row['name']); ?></td>
                        <td><?php echo ucfirst($row['type_pro']); ?></td>
                        <td><?php echo $row['tt_pro']; ?></td>
                        <td><?php echo number_format($row['price'], 2, ',', ' '); ?> €</td>
                        <td><?php echo number_format($row['tt_pro'] * $row['price'], 2, ',', ' '); ?> €</td>
                    </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
            <?php else: ?>
            <div class="empty-state">
                <i class="fas fa-shopping-cart"></i>
                <p>Aucune vente enregistrée aujourd'hui</p>
            </div>
            <?php endif; ?>
        </div>
    </div>

    <?php
    // Fermeture des connexions
    mysqli_stmt_close($stmt);
    mysqli_stmt_close($stmt_totals);
    mysqli_close($conn);
    ?>
</body>
</html>