<?php
session_start();
include 'db_connect.php';


// Fonction pour sécuriser les entrées
function clean_input($data) {
    global $conn;
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    return $conn->real_escape_string($data);
}

// Vérification si la requête est en AJAX et contient les données nécessaires
if (isset($_POST['action']) && $_POST['action'] == 'enregistrer_vente') {
    // Récupération des données envoyées par AJAX
    $utilisateur_id = isset($_POST['utilisateur_id']) ? clean_input($_POST['utilisateur_id']) : 0;
    $montant_total = clean_input($_POST['montant_total']);
    $montant_recu = clean_input($_POST['montant_recu']);
    $monnaie_rendu = $montant_recu - $montant_total;
    $moyen_paiement = clean_input($_POST['moyen_paiement']);
    $nom_pro = clean_input($_POST['nom_pro']);
    $tt_pro = clean_input($_POST['tt_pro']);

    // Préparation de la requête SQL
    $sql = "INSERT INTO ventes (utilisateur_id, montant_total, montant_recu, monnaie_rendu, 
            moyen_paiement, date_heure, nom_pro, tt_pro) 
            VALUES (?, ?, ?, ?, ?, NOW(), ?, ?)";

    // Préparation et exécution de la requête
    if ($stmt = $conn->prepare($sql)) {
        $stmt->bind_param("idddsss", 
            $utilisateur_id,
            $montant_total,
            $montant_recu,
            $monnaie_rendu,
            $moyen_paiement,
            $nom_pro,
            $tt_pro
        );
        
        $response = array();
        if ($stmt->execute()) {
            $response['success'] = true;
            $response['message'] = "Vente enregistrée avec succès!";
        } else {
            $response['success'] = false;
            $response['message'] = "Erreur lors de l'enregistrement de la vente: " . $stmt->error;
        }
        
        $stmt->close();
        // Envoi de la réponse au format JSON
        echo json_encode($response);
        exit();
    }
}

// Si ce n'est pas une requête AJAX, redirigez vers dashboard.php
if (!isset($_POST['action'])) {
    header("Location: dashboard.php");
    exit();
}
?>

<!-- Code à ajouter dans votre dashboard.php -->
<script>
// Fonction pour enregistrer la vente
function enregistrerVente(montantRecu) {
    // Récupération des données du panier depuis le dashboard
    const montantTotal = document.getElementById('montant_total').value;
    const moyenPaiement = document.getElementById('moyen_paiement').value;
    const nomProduits = document.getElementById('nom_produits').value;
    const quantiteProduits = document.getElementById('quantite_produits').value;
    const utilisateurId = document.getElementById('utilisateur_id').value;

    // Création de l'objet de données
    const donnees = {
        action: 'enregistrer_vente',
        utilisateur_id: utilisateurId,
        montant_total: montantTotal,
        montant_recu: montantRecu,
        moyen_paiement: moyenPaiement,
        nom_pro: nomProduits,
        tt_pro: quantiteProduits
    };

    // Envoi des données via AJAX
    fetch('traitement_vente.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        body: new URLSearchParams(donnees)
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            alert(data.message);
            // Réinitialisation du panier ou redirection
            window.location.reload();
        } else {
            alert("Erreur : " + data.message);
        }
    })
    .catch(error => {
        console.error('Erreur:', error);
        alert("Une erreur est survenue lors de l'enregistrement de la vente");
    });
}

// Exemple d'utilisation dans votre formulaire de dashboard
document.getElementById('form_validation_vente').addEventListener('submit', function(e) {
    e.preventDefault();
    const montantRecu = document.getElementById('montant_recu').value;
    enregistrerVente(montantRecu);
});
</script>