<?php
session_start();
include 'db_connect.php';

$conn->set_charset("utf8");

// Fonction pour sécuriser les entrées
function secure_input($data) {
    global $conn;
    return $conn->real_escape_string(htmlspecialchars(trim($data)));
}

// Détermine le mode d'affichage (tous les produits ou produits en alerte)
$mode = isset($_GET['mode']) ? $_GET['mode'] : 'all';
$search = isset($_GET['search']) ? secure_input($_GET['search']) : '';

// Construction de la requête SQL
$sql = "SELECT * FROM products WHERE 1=1";
if ($mode === 'alert') {
    $sql .= " AND stock <= seuil_alerte";
}
if (!empty($search)) {
    $sql .= " AND (name LIKE '%$search%' OR barcode LIKE '%$search%')";
}
$result = $conn->query($sql);
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestion des Produits</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Arial', sans-serif;
            margin: 0;
            padding: 20px;
            background: linear-gradient(rgba(255, 255, 255, 0.9), rgba(255, 255, 255, 0.9)),
                        url('https://via.placeholder.com/1920x1080') no-repeat center center fixed;
            background-size: cover;
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            background: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 15px rgba(0,0,0,0.1);
        }

        .buttons {
            margin-bottom: 20px;
            display: flex;
            gap: 10px;
        }

        .btn {
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-weight: bold;
            transition: background-color 0.3s;
        }

        .btn-primary {
            background-color: #4CAF50;
            color: white;
        }

        .btn-warning {
            background-color: #ff9800;
            color: white;
        }

        .btn:hover {
            opacity: 0.9;
        }

        .search-container {
            margin-bottom: 20px;
        }

        .search-input {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 5px;
            font-size: 16px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background: white;
        }

        th, td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }

        th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        tr:hover {
            background-color: #f9f9f9;
        }

        .alert {
            background-color: #ffebee;
        }

        @media (max-width: 768px) {
            .container {
                padding: 10px;
            }

            table {
                display: block;
                overflow-x: auto;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Gestion des Produits</h1>
        
        <div class="buttons">
            <a href="?mode=all" class="btn btn-primary">
                <i class="fas fa-box"></i> Tous les produits
            </a>
            <a href="?mode=alert" class="btn btn-warning">
                <i class="fas fa-exclamation-triangle"></i> Produits en alerte
            </a>
        </div>

        <div class="search-container">
            <input type="text" 
                   class="search-input" 
                   placeholder="Rechercher par nom ou code-barres..." 
                   value="<?php echo htmlspecialchars($search); ?>"
                   id="searchInput">
        </div>

        <table>
            <thead>
                <tr>
                    <th>Code-barres</th>
                    <th>Nom</th>
                    <th>Quantité</th>
                    <th>Prix</th>
                    <th>Seuil d'alerte</th>
                </tr>
            </thead>
            <tbody>
                <?php
                if ($result->num_rows > 0) {
                    while($row = $result->fetch_assoc()) {
                        $alertClass = ($row['stock'] <= $row['seuil_alerte']) ? 'alert' : '';
                        echo "<tr class='$alertClass'>";
                        echo "<td>" . htmlspecialchars($row['barcode']) . "</td>";
                        echo "<td>" . htmlspecialchars($row['name']) . "</td>";
                        echo "<td>" . htmlspecialchars($row['stock']) . "</td>";
                        echo "<td>" . htmlspecialchars($row['price']) . " €</td>";
                        echo "<td>" . htmlspecialchars($row['seuil_alerte']) . "</td>";
                        echo "</tr>";
                    }
                } else {
                    echo "<tr><td colspan='5'>Aucun produit trouvé</td></tr>";
                }
                ?>
            </tbody>
        </table>
    </div>

    <script>
        document.getElementById('searchInput').addEventListener('input', function(e) {
            const searchValue = e.target.value;
            const currentMode = new URLSearchParams(window.location.search).get('mode') || 'all';
            window.location.href = `?mode=${currentMode}&search=${searchValue}`;
        });
    </script>
</body>
</html>

<?php
$conn->close();
?>