<?php
session_start();
include 'db_connect.php';

// D'abord, ajouter les colonnes si elles n'existent pas déjà
$sql_alter = "
    ALTER TABLE ventes 
    ADD COLUMN IF NOT EXISTS nom_pro VARCHAR(255),
    ADD COLUMN IF NOT EXISTS tt_pro INT DEFAULT 0
";

if ($conn->query($sql_alter) === FALSE) {
    die("Erreur lors de l'ajout des colonnes : " . $conn->error);
}

// Mettre à jour les champs nom_pro et tt_pro
$sql_update = "
    UPDATE ventes v
    SET 
        v.nom_pro = (
            SELECT GROUP_CONCAT(p.name SEPARATOR ', ')
            FROM products p
            WHERE FIND_IN_SET(p.id, v.produits_id)
        ),
        v.tt_pro = (
            SELECT COUNT(*)
            FROM products p
            WHERE FIND_IN_SET(p.id, v.produits_id)
        )
    WHERE v.nom_pro IS NULL 
    OR v.tt_pro = 0
";

if ($conn->query($sql_update) === TRUE) {
    echo "Mise à jour réussie";
} else {
    echo "Erreur lors de la mise à jour : " . $conn->error;
}

// Créer un trigger pour les mises à jour automatiques futures
$sql_trigger = "
    CREATE TRIGGER IF NOT EXISTS update_ventes_after_insert 
    AFTER INSERT ON ventes
    FOR EACH ROW
    BEGIN
        UPDATE ventes 
        SET 
            nom_pro = (
                SELECT GROUP_CONCAT(p.nom SEPARATOR ', ')
                FROM products p
                WHERE FIND_IN_SET(p.id, NEW.produits_id)
            ),
            tt_pro = (
                SELECT COUNT(*)
                FROM products p
                WHERE FIND_IN_SET(p.id, NEW.produits_id)
            )
        WHERE id = NEW.id;
    END;
";

if ($conn->multi_query($sql_trigger) === FALSE) {
    echo "Erreur lors de la création du trigger : " . $conn->error;
}

$conn->close();
?>